@@ -4,6 +4,7 @@ namespace dokuwiki\Action;
 
 use dokuwiki\Action\Exception\FatalException;
 use dokuwiki\Sitemap\Mapper;
+use dokuwiki\Utf8\PhpString;
 
 /**
  * Class Sitemap
@@ -48,7 +49,7 @@ class Sitemap extends AbstractAction {
         if(is_readable($sitemap)) {
             // Send headers
             header('Content-Type: ' . $mime);
-            header('Content-Disposition: attachment; filename=' . \dokuwiki\Utf8\PhpString::basename($sitemap));
+            header('Content-Disposition: attachment; filename=' . PhpString::basename($sitemap));
 
             http_conditionalRequest(filemtime($sitemap));
 
