@@ -11,14 +11,18 @@ class Admin extends AbstractItem {
 
     /** @inheritdoc */
     public function __construct() {
-        global $INFO;
         parent::__construct();
 
         $this->svg = DOKU_INC . 'lib/images/menu/settings.svg';
+    }
 
-        if(!$INFO['ismanager']) {
-            throw new \RuntimeException("admin is for managers only");
-        }
+    /** @inheritdoc */
+    public function visibleInContext($ctx)
+    {
+        global $INFO;
+        if(!$INFO['ismanager']) return false;
+
+        return parent::visibleInContext($ctx);
     }
 
 }
