@@ -6,7 +6,9 @@
  * @author     Tom N Harris <tnharris@whoopdedo.org>
  */
 
-if(!defined('DOKU_INC')) die('meh.');
+// phpcs:disable Squiz.Classes.ValidClassName.NotCamelCaps
+// phpcs:disable PSR2.Classes.PropertyDeclaration.Underscore
+
 
 /**
  * Class for creating simple HTML forms.
@@ -23,22 +25,27 @@ if(!defined('DOKU_INC')) die('meh.');
  *
  * See the form_make* functions later in this file.
  *
+ * Please note that even though this class is technically deprecated (use dokuwiki\Form instead),
+ * it is still widely used in the core and the related form events. Until those have been rewritten,
+ * this will continue to be used
+ *
+ * @deprecated 2019-07-14
  * @author Tom N Harris <tnharris@whoopdedo.org>
  */
-class Doku_Form {
-
+class Doku_Form
+{
     // Form id attribute
-    var $params = array();
+    public $params = array();
 
     // Draw a border around form fields.
     // Adds <fieldset></fieldset> around the elements
-    var $_infieldset = false;
+    public $_infieldset = false;
 
     // Hidden form fields.
-    var $_hidden = array();
+    public $_hidden = array();
 
     // Array of pseudo-tags
-    var $_content = array();
+    public $_content = array();
 
     /**
      * Constructor
@@ -47,19 +54,17 @@ class Doku_Form {
      * with up to four parameters is deprecated, instead the first parameter
      * should be an array with parameters.
      *
-     * @param   mixed   $params  Parameters for the HTML form element; Using the
-     *                           deprecated calling convention this is the ID
-     *                           attribute of the form
-     * @param   string  $action  (optional, deprecated) submit URL, defaults to
-     *                                                  current page
-     * @param   string  $method  (optional, deprecated) 'POST' or 'GET', default
-     *                                                  is POST
-     * @param   string  $enctype (optional, deprecated) Encoding type of the
-     *                                                  data
+     * @param mixed       $params  Parameters for the HTML form element; Using the deprecated
+     *                             calling convention this is the ID attribute of the form
+     * @param bool|string $action  (optional, deprecated) submit URL, defaults to current page
+     * @param bool|string $method  (optional, deprecated) 'POST' or 'GET', default is POST
+     * @param bool|string $enctype (optional, deprecated) Encoding type of the data
+     *
      * @author  Tom N Harris <tnharris@whoopdedo.org>
      */
-    function Doku_Form($params, $action=false, $method=false, $enctype=false) {
-        if(!is_array($params)) {
+    public function __construct($params, $action=false, $method=false, $enctype=false)
+    {
+        if (!is_array($params)) {
             $this->params = array('id' => $params);
             if ($action !== false) $this->params['action'] = $action;
             if ($method !== false) $this->params['method'] = strtolower($method);
@@ -88,9 +93,11 @@ class Doku_Form {
      * Usually results in a border drawn around the form.
      *
      * @param   string  $legend Label that will be printed with the border.
+     *
      * @author  Tom N Harris <tnharris@whoopdedo.org>
      */
-    function startFieldset($legend) {
+    public function startFieldset($legend)
+    {
         if ($this->_infieldset) {
             $this->addElement(array('_elem'=>'closefieldset'));
         }
@@ -103,7 +110,8 @@ class Doku_Form {
      *
      * @author  Tom N Harris <tnharris@whoopdedo.org>
      */
-    function endFieldset() {
+    public function endFieldset()
+    {
         if ($this->_infieldset) {
             $this->addElement(array('_elem'=>'closefieldset'));
         }
@@ -119,9 +127,11 @@ class Doku_Form {
      *
      * @param   string  $name   Field name.
      * @param   string  $value  Field value. If null, remove a previously added field.
+     *
      * @author  Tom N Harris <tnharris@whoopdedo.org>
      */
-    function addHidden($name, $value) {
+    public function addHidden($name, $value)
+    {
         if (is_null($value))
             unset($this->_hidden[$name]);
         else
@@ -135,10 +145,12 @@ class Doku_Form {
      * The element can be either a pseudo-tag or string.
      * If string, it is printed without escaping special chars.   *
      *
-     * @param   string  $elem   Pseudo-tag or string to add to the form.
+     * @param   string|array  $elem   Pseudo-tag or string to add to the form.
+     *
      * @author  Tom N Harris <tnharris@whoopdedo.org>
      */
-    function addElement($elem) {
+    public function addElement($elem)
+    {
         $this->_content[] = $elem;
     }
 
@@ -147,11 +159,13 @@ class Doku_Form {
      *
      * Inserts a content element at a position.
      *
-     * @param   string  $pos    0-based index where the element will be inserted.
-     * @param   string  $elem   Pseudo-tag or string to add to the form.
+     * @param   string       $pos  0-based index where the element will be inserted.
+     * @param   string|array $elem Pseudo-tag or string to add to the form.
+     *
      * @author  Tom N Harris <tnharris@whoopdedo.org>
      */
-    function insertElement($pos, $elem) {
+    public function insertElement($pos, $elem)
+    {
         array_splice($this->_content, $pos, 0, array($elem));
     }
 
@@ -160,11 +174,13 @@ class Doku_Form {
      *
      * Replace with NULL to remove an element.
      *
-     * @param   int     $pos    0-based index the element will be placed at.
-     * @param   string  $elem   Pseudo-tag or string to add to the form.
+     * @param   int          $pos  0-based index the element will be placed at.
+     * @param   string|array $elem Pseudo-tag or string to add to the form.
+     *
      * @author  Tom N Harris <tnharris@whoopdedo.org>
      */
-    function replaceElement($pos, $elem) {
+    public function replaceElement($pos, $elem)
+    {
         $rep = array();
         if (!is_null($elem)) $rep[] = $elem;
         array_splice($this->_content, $pos, 1, $rep);
@@ -176,11 +192,13 @@ class Doku_Form {
      * Gets the position of the first of a type of element.
      *
      * @param   string  $type   Element type to look for.
-     * @return  array   pseudo-element if found, false otherwise
+     * @return  int|false     position of element if found, otherwise false
+     *
      * @author  Tom N Harris <tnharris@whoopdedo.org>
      */
-    function findElementByType($type) {
-        foreach ($this->_content as $pos=>$elem) {
+    public function findElementByType($type)
+    {
+        foreach ($this->_content as $pos => $elem) {
             if (is_array($elem) && $elem['_elem'] == $type)
                 return $pos;
         }
@@ -193,11 +211,13 @@ class Doku_Form {
      * Gets the position of the element with an ID attribute.
      *
      * @param   string  $id     ID of the element to find.
-     * @return  array   pseudo-element if found, false otherwise
+     * @return  int|false     position of element if found, otherwise false
+     *
      * @author  Tom N Harris <tnharris@whoopdedo.org>
      */
-    function findElementById($id) {
-        foreach ($this->_content as $pos=>$elem) {
+    public function findElementById($id)
+    {
+        foreach ($this->_content as $pos => $elem) {
             if (is_array($elem) && isset($elem['id']) && $elem['id'] == $id)
                 return $pos;
         }
@@ -211,11 +231,13 @@ class Doku_Form {
      *
      * @param   string  $name   Attribute name.
      * @param   string  $value  Attribute value.
-     * @return  array   pseudo-element if found, false otherwise
+     * @return  int|false     position of element if found, otherwise false
+     *
      * @author  Tom N Harris <tnharris@whoopdedo.org>
      */
-    function findElementByAttribute($name, $value) {
-        foreach ($this->_content as $pos=>$elem) {
+    public function findElementByAttribute($name, $value)
+    {
+        foreach ($this->_content as $pos => $elem) {
             if (is_array($elem) && isset($elem[$name]) && $elem[$name] == $value)
                 return $pos;
         }
@@ -230,10 +252,12 @@ class Doku_Form {
      * first (underflow) or last (overflow) element.
      *
      * @param   int     $pos    0-based index
-     * @return  arrayreference  pseudo-element
+     * @return  array reference  pseudo-element
+     *
      * @author  Tom N Harris <tnharris@whoopdedo.org>
      */
-    function &getElementAt($pos) {
+    public function &getElementAt($pos)
+    {
         if ($pos < 0) $pos = count($this->_content) + $pos;
         if ($pos < 0) $pos = 0;
         if ($pos >= count($this->_content)) $pos = count($this->_content) - 1;
@@ -247,14 +271,17 @@ class Doku_Form {
      * 'form_$type'. The function should return the HTML to be printed.
      *
      * @author  Tom N Harris <tnharris@whoopdedo.org>
+     *
+     * @return string html of the form
      */
-    function getForm() {
+    public function getForm()
+    {
         global $lang;
         $form = '';
         $this->params['accept-charset'] = $lang['encoding'];
-        $form .= '<form ' . buildAttributes($this->params,false) . '><div class="no">' . DOKU_LF;
+        $form .= '<form '. buildAttributes($this->params,false) .'><div class="no">'. DOKU_LF;
         if (!empty($this->_hidden)) {
-            foreach ($this->_hidden as $name=>$value)
+            foreach ($this->_hidden as $name => $value)
                 $form .= form_hidden(array('name'=>$name, 'value'=>$value));
         }
         foreach ($this->_content as $element) {
@@ -278,7 +305,8 @@ class Doku_Form {
      *
      * wraps around getForm()
      */
-    function printForm(){
+    public function printForm()
+    {
         echo $this->getForm();
     }
 
@@ -294,7 +322,8 @@ class Doku_Form {
      * @author Adrian Lang <lang@cosmocode.de>
      */
 
-    function addRadioSet($name, $entries) {
+    public function addRadioSet($name, $entries)
+    {
         global $INPUT;
         $value = (array_key_exists($INPUT->post->str($name), $entries)) ?
                  $INPUT->str($name) : key($entries);
@@ -314,6 +343,7 @@ class Doku_Form {
  * @param   string  $tag    Tag name.
  * @param   array   $attrs  Optional attributes.
  * @return  array   pseudo-tag
+ *
  * @author  Tom N Harris <tnharris@whoopdedo.org>
  */
 function form_makeTag($tag, $attrs=array()) {
@@ -330,6 +360,7 @@ function form_makeTag($tag, $attrs=array()) {
  * @param   string  $tag    Tag name.
  * @param   array   $attrs  Optional attributes.
  * @return  array   pseudo-tag
+ *
  * @author  Tom N Harris <tnharris@whoopdedo.org>
  */
 function form_makeOpenTag($tag, $attrs=array()) {
@@ -345,6 +376,7 @@ function form_makeOpenTag($tag, $attrs=array()) {
  *
  * @param   string  $tag    Tag name.
  * @return  array   pseudo-tag
+ *
  * @author  Tom N Harris <tnharris@whoopdedo.org>
  */
 function form_makeCloseTag($tag) {
@@ -362,6 +394,7 @@ function form_makeCloseTag($tag) {
  * @param   string  $text   Text to fill the field with.
  * @param   array   $attrs  Optional attributes.
  * @return  array   pseudo-tag
+ *
  * @author  Tom N Harris <tnharris@whoopdedo.org>
  */
 function form_makeWikiText($text, $attrs=array()) {
@@ -382,14 +415,15 @@ function form_makeWikiText($text, $attrs=array()) {
  * @param   string  $value  (optional) Displayed label. Uses $act if not provided.
  * @param   array   $attrs  Optional attributes.
  * @return  array   pseudo-tag
+ *
  * @author  Tom N Harris <tnharris@whoopdedo.org>
  */
 function form_makeButton($type, $act, $value='', $attrs=array()) {
     if ($value == '') $value = $act;
     $elem = array('_elem'=>'button', 'type'=>$type, '_action'=>$act,
-                        'value'=>$value, 'class'=>'button');
+                        'value'=>$value);
     if (!empty($attrs['accesskey']) && empty($attrs['title'])) {
-        $attrs['title'] = $value . ' ['.strtoupper($attrs['accesskey']).']';
+        $attrs['title'] = $value .' ['. strtoupper($attrs['accesskey']) .']';
     }
     return array_merge($elem, $attrs);
 }
@@ -410,6 +444,7 @@ function form_makeButton($type, $act, $value='', $attrs=array()) {
  *                          reference it with a 'for' attribute.
  * @param   array   $attrs  Optional attributes.
  * @return  array   pseudo-tag
+ *
  * @author  Tom N Harris <tnharris@whoopdedo.org>
  */
 function form_makeField($type, $name, $value='', $label=null, $id='', $class='', $attrs=array()) {
@@ -427,6 +462,16 @@ function form_makeField($type, $name, $value='', $label=null, $id='', $class='',
  *
  * @see     form_makeField
  * @author  Tom N Harris <tnharris@whoopdedo.org>
+ *
+ * @param string $type
+ * @param string $name
+ * @param string $value
+ * @param null|string $label
+ * @param string $id
+ * @param string $class
+ * @param array $attrs
+ *
+ * @return array
  */
 function form_makeFieldRight($type, $name, $value='', $label=null, $id='', $class='', $attrs=array()) {
     if (is_null($label)) $label = $name;
@@ -442,6 +487,15 @@ function form_makeFieldRight($type, $name, $value='', $label=null, $id='', $clas
  *
  * @see     form_makeField
  * @author  Tom N Harris <tnharris@whoopdedo.org>
+ *
+ * @param string $name
+ * @param string $value
+ * @param null|string $label
+ * @param string $id
+ * @param string $class
+ * @param array $attrs
+ *
+ * @return array
  */
 function form_makeTextField($name, $value='', $label=null, $id='', $class='', $attrs=array()) {
     if (is_null($label)) $label = $name;
@@ -458,6 +512,14 @@ function form_makeTextField($name, $value='', $label=null, $id='', $class='', $a
  *
  * @see     form_makeField
  * @author  Tom N Harris <tnharris@whoopdedo.org>
+ *
+ * @param string $name
+ * @param null|string $label
+ * @param string $id
+ * @param string $class
+ * @param array $attrs
+ *
+ * @return array
  */
 function form_makePasswordField($name, $label=null, $id='', $class='', $attrs=array()) {
     if (is_null($label)) $label = $name;
@@ -473,6 +535,14 @@ function form_makePasswordField($name, $label=null, $id='', $class='', $attrs=ar
  *
  * @see     form_makeField
  * @author  Michael Klier <chi@chimeric.de>
+ *
+ * @param string $name
+ * @param null|string $label
+ * @param string $id
+ * @param string $class
+ * @param array $attrs
+ *
+ * @return array
  */
 function form_makeFileField($name, $label=null, $id='', $class='', $attrs=array()) {
     if (is_null($label)) $label = $name;
@@ -490,6 +560,15 @@ function form_makeFileField($name, $label=null, $id='', $class='', $attrs=array(
  *
  * @see     form_makeFieldRight
  * @author  Tom N Harris <tnharris@whoopdedo.org>
+ *
+ * @param string $name
+ * @param string $value
+ * @param null|string $label
+ * @param string $id
+ * @param string $class
+ * @param array $attrs
+ *
+ * @return array
  */
 function form_makeCheckboxField($name, $value='1', $label=null, $id='', $class='', $attrs=array()) {
     if (is_null($label)) $label = $name;
@@ -506,6 +585,15 @@ function form_makeCheckboxField($name, $value='1', $label=null, $id='', $class='
  *
  * @see     form_makeFieldRight
  * @author  Tom N Harris <tnharris@whoopdedo.org>
+ *
+ * @param string $name
+ * @param string $value
+ * @param null|string $label
+ * @param string $id
+ * @param string $class
+ * @param array $attrs
+ *
+ * @return array
  */
 function form_makeRadioField($name, $value='1', $label=null, $id='', $class='', $attrs=array()) {
     if (is_null($label)) $label = $name;
@@ -526,6 +614,18 @@ function form_makeRadioField($name, $value='1', $label=null, $id='', $class='',
  * a string.
  *
  * @author  Tom N Harris <tnharris@whoopdedo.org>
+ *
+ * @param string           $name     Name attribute of the input.
+ * @param string[]|array[] $values   The list of values can be strings, arrays of (value,text),
+ *                                   or an associative array with the values as keys and labels as values.
+ * @param string|int       $selected default selected value, string or index number
+ * @param string           $class    Class attribute of the label. If this is 'block',
+ *                                   then a line break will be added after the field.
+ * @param string           $label    Label that will be printed before the input.
+ * @param string           $id       ID attribute of the input. If set, the label will
+ *                                   reference it with a 'for' attribute.
+ * @param array            $attrs    Optional attributes.
+ * @return array   pseudo-tag
  */
 function form_makeMenuField($name, $values, $selected='', $label=null, $id='', $class='', $attrs=array()) {
     if (is_null($label)) $label = $name;
@@ -533,17 +633,17 @@ function form_makeMenuField($name, $values, $selected='', $label=null, $id='', $
     reset($values);
     // FIXME: php doesn't know the difference between a string and an integer
     if (is_string(key($values))) {
-        foreach ($values as $val=>$text) {
-            $options[] = array($val,$text, (!is_null($selected) && $val==$selected));
+        foreach ($values as $val => $text) {
+            $options[] = array($val, $text, (!is_null($selected) && $val==$selected));
         }
     } else {
         if (is_integer($selected)) $selected = $values[$selected];
         foreach ($values as $val) {
             if (is_array($val))
-                @list($val,$text) = $val;
+                @list($val, $text) = $val;
             else
                 $text = null;
-            $options[] = array($val,$text,$val===$selected);
+            $options[] = array($val, $text, $val===$selected);
         }
     }
     $elem = array('_elem'=>'menufield', '_options'=>$options, '_text'=>$label, '_class'=>$class,
@@ -560,27 +660,42 @@ function form_makeMenuField($name, $values, $selected='', $label=null, $id='', $
  * Items are selected by supplying its value or an array of values.
  *
  * @author  Tom N Harris <tnharris@whoopdedo.org>
+ *
+ * @param string           $name     Name attribute of the input.
+ * @param string[]|array[] $values   The list of values can be strings, arrays of (value,text),
+ *                                   or an associative array with the values as keys and labels as values.
+ * @param array|string     $selected value or array of values of the items that need to be selected
+ * @param string           $class    Class attribute of the label. If this is 'block',
+ *                                   then a line break will be added after the field.
+ * @param string           $label    Label that will be printed before the input.
+ * @param string           $id       ID attribute of the input. If set, the label will
+ *                                   reference it with a 'for' attribute.
+ * @param array            $attrs    Optional attributes.
+ * @return array   pseudo-tag
  */
 function form_makeListboxField($name, $values, $selected='', $label=null, $id='', $class='', $attrs=array()) {
     if (is_null($label)) $label = $name;
     $options = array();
     reset($values);
-    if (is_null($selected) || $selected == '')
+    if (is_null($selected) || $selected == '') {
         $selected = array();
-    elseif (!is_array($selected))
+    } elseif (!is_array($selected)) {
         $selected = array($selected);
+    }
     // FIXME: php doesn't know the difference between a string and an integer
     if (is_string(key($values))) {
-        foreach ($values as $val=>$text) {
-            $options[] = array($val,$text,in_array($val,$selected));
+        foreach ($values as $val => $text) {
+            $options[] = array($val, $text, in_array($val,$selected));
         }
     } else {
         foreach ($values as $val) {
-            if (is_array($val))
-                @list($val,$text) = $val;
-            else
+            $disabled = false;
+            if (is_array($val)) {
+                @list($val, $text, $disabled) = $val;
+            } else {
                 $text = null;
-            $options[] = array($val,$text,in_array($val,$selected));
+            }
+            $options[] = array($val, $text, in_array($val, $selected), $disabled);
         }
     }
     $elem = array('_elem'=>'listboxfield', '_options'=>$options, '_text'=>$label, '_class'=>$class,
@@ -596,9 +711,12 @@ function form_makeListboxField($name, $values, $selected='', $label=null, $id=''
  * Attributes are passed to buildAttributes()
  *
  * @author  Tom N Harris <tnharris@whoopdedo.org>
+ *
+ * @param array $attrs attributes
+ * @return string html of tag
  */
 function form_tag($attrs) {
-    return '<'.$attrs['_tag'].' '.buildAttributes($attrs,true).'/>';
+    return '<'.$attrs['_tag'].' '. buildAttributes($attrs,true) .'/>';
 }
 
 /**
@@ -609,9 +727,12 @@ function form_tag($attrs) {
  * Attributes are passed to buildAttributes()
  *
  * @author  Tom N Harris <tnharris@whoopdedo.org>
+ *
+ * @param array $attrs attributes
+ * @return string html of tag
  */
 function form_opentag($attrs) {
-    return '<'.$attrs['_tag'].' '.buildAttributes($attrs,true).'>';
+    return '<'.$attrs['_tag'].' '. buildAttributes($attrs,true) .'>';
 }
 
 /**
@@ -622,6 +743,9 @@ function form_opentag($attrs) {
  * There are no attributes.
  *
  * @author  Tom N Harris <tnharris@whoopdedo.org>
+ *
+ * @param array $attrs attributes
+ * @return string html of tag
  */
 function form_closetag($attrs) {
     return '</'.$attrs['_tag'].'>';
@@ -635,9 +759,12 @@ function form_closetag($attrs) {
  * Attributes are passed to buildAttributes()
  *
  * @author  Tom N Harris <tnharris@whoopdedo.org>
+ *
+ * @param array $attrs attributes
+ * @return string html
  */
 function form_openfieldset($attrs) {
-    $s = '<fieldset '.buildAttributes($attrs,true).'>';
+    $s = '<fieldset '. buildAttributes($attrs,true) .'>';
     if (!is_null($attrs['_legend'])) $s .= '<legend>'.$attrs['_legend'].'</legend>';
     return $s;
 }
@@ -649,6 +776,8 @@ function form_openfieldset($attrs) {
  * There are no attributes.
  *
  * @author  Tom N Harris <tnharris@whoopdedo.org>
+ *
+ * @return string html
  */
 function form_closefieldset() {
     return '</fieldset>';
@@ -662,9 +791,12 @@ function form_closefieldset() {
  * Value is passed to formText()
  *
  * @author  Tom N Harris <tnharris@whoopdedo.org>
+ *
+ * @param array $attrs attributes
+ * @return string html
  */
 function form_hidden($attrs) {
-    return '<input type="hidden" name="'.$attrs['name'].'" value="'.formText($attrs['value']).'" />';
+    return '<input type="hidden" name="'.$attrs['name'].'" value="'. formText($attrs['value']) .'" />';
 }
 
 /**
@@ -675,15 +807,18 @@ function form_hidden($attrs) {
  * Text will be passed to formText(), attributes to buildAttributes()
  *
  * @author  Tom N Harris <tnharris@whoopdedo.org>
+ *
+ * @param array $attrs attributes
+ * @return string html
  */
 function form_wikitext($attrs) {
     // mandatory attributes
     unset($attrs['name']);
     unset($attrs['id']);
     return '<textarea name="wikitext" id="wiki__text" dir="auto" '
-                 .buildAttributes($attrs,true).'>'.DOKU_LF
-                 .formText($attrs['_text'])
-                 .'</textarea>';
+                . buildAttributes($attrs,true).'>'.DOKU_LF
+                . formText($attrs['_text'])
+                .'</textarea>';
 }
 
 /**
@@ -694,10 +829,15 @@ function form_wikitext($attrs) {
  * Other attributes are passed to buildAttributes()
  *
  * @author  Tom N Harris <tnharris@whoopdedo.org>
+ *
+ * @param array $attrs attributes
+ * @return string html
  */
 function form_button($attrs) {
     $p = (!empty($attrs['_action'])) ? 'name="do['.$attrs['_action'].']" ' : '';
-    return '<input '.$p.buildAttributes($attrs,true).' />';
+    $value = $attrs['value'];
+    unset($attrs['value']);
+    return '<button '.$p. buildAttributes($attrs,true) .'>'.$value.'</button>';
 }
 
 /**
@@ -709,13 +849,16 @@ function form_button($attrs) {
  * Other attributes are passed to buildAttributes() for the input tag.
  *
  * @author  Tom N Harris <tnharris@whoopdedo.org>
+ *
+ * @param array $attrs attributes
+ * @return string html
  */
 function form_field($attrs) {
     $s = '<label';
     if ($attrs['_class']) $s .= ' class="'.$attrs['_class'].'"';
     if (!empty($attrs['id'])) $s .= ' for="'.$attrs['id'].'"';
     $s .= '><span>'.$attrs['_text'].'</span>';
-    $s .= ' <input '.buildAttributes($attrs,true).' /></label>';
+    $s .= ' <input '. buildAttributes($attrs,true) .' /></label>';
     if (preg_match('/(^| )block($| )/', $attrs['_class']))
         $s .= '<br />';
     return $s;
@@ -730,12 +873,15 @@ function form_field($attrs) {
  * Other attributes are passed to buildAttributes() for the input tag.
  *
  * @author  Tom N Harris <tnharris@whoopdedo.org>
+ *
+ * @param array $attrs attributes
+ * @return string html
  */
 function form_fieldright($attrs) {
     $s = '<label';
     if ($attrs['_class']) $s .= ' class="'.$attrs['_class'].'"';
     if (!empty($attrs['id'])) $s .= ' for="'.$attrs['id'].'"';
-    $s .= '><input '.buildAttributes($attrs,true).' />';
+    $s .= '><input '. buildAttributes($attrs,true) .' />';
     $s .= ' <span>'.$attrs['_text'].'</span></label>';
     if (preg_match('/(^| )block($| )/', $attrs['_class']))
         $s .= '<br />';
@@ -751,6 +897,9 @@ function form_fieldright($attrs) {
  * Other attributes are passed to buildAttributes() for the input tag.
  *
  * @author  Tom N Harris <tnharris@whoopdedo.org>
+ *
+ * @param array $attrs attributes
+ * @return string html
  */
 function form_textfield($attrs) {
     // mandatory attributes
@@ -759,7 +908,7 @@ function form_textfield($attrs) {
     if ($attrs['_class']) $s .= ' class="'.$attrs['_class'].'"';
     if (!empty($attrs['id'])) $s .= ' for="'.$attrs['id'].'"';
     $s .= '><span>'.$attrs['_text'].'</span> ';
-    $s .= '<input type="text" '.buildAttributes($attrs,true).' /></label>';
+    $s .= '<input type="text" '. buildAttributes($attrs,true) .' /></label>';
     if (preg_match('/(^| )block($| )/', $attrs['_class']))
         $s .= '<br />';
     return $s;
@@ -774,6 +923,9 @@ function form_textfield($attrs) {
  * Other attributes are passed to buildAttributes() for the input tag.
  *
  * @author  Tom N Harris <tnharris@whoopdedo.org>
+ *
+ * @param array $attrs attributes
+ * @return string html
  */
 function form_passwordfield($attrs) {
     // mandatory attributes
@@ -782,7 +934,7 @@ function form_passwordfield($attrs) {
     if ($attrs['_class']) $s .= ' class="'.$attrs['_class'].'"';
     if (!empty($attrs['id'])) $s .= ' for="'.$attrs['id'].'"';
     $s .= '><span>'.$attrs['_text'].'</span> ';
-    $s .= '<input type="password" '.buildAttributes($attrs,true).' /></label>';
+    $s .= '<input type="password" '. buildAttributes($attrs,true) .' /></label>';
     if (preg_match('/(^| )block($| )/', $attrs['_class']))
         $s .= '<br />';
     return $s;
@@ -799,13 +951,16 @@ function form_passwordfield($attrs) {
  * Other attributes are passed to buildAttributes() for the input tag
  *
  * @author  Michael Klier <chi@chimeric.de>
+ *
+ * @param array $attrs attributes
+ * @return string html
  */
 function form_filefield($attrs) {
     $s = '<label';
     if ($attrs['_class']) $s .= ' class="'.$attrs['_class'].'"';
     if (!empty($attrs['id'])) $s .= ' for="'.$attrs['id'].'"';
     $s .= '><span>'.$attrs['_text'].'</span> ';
-    $s .= '<input type="file" '.buildAttributes($attrs,true);
+    $s .= '<input type="file" '. buildAttributes($attrs,true);
     if (!empty($attrs['_maxlength'])) $s .= ' maxlength="'.$attrs['_maxlength'].'"';
     if (!empty($attrs['_accept'])) $s .= ' accept="'.$attrs['_accept'].'"';
     $s .= ' /></label>';
@@ -825,6 +980,9 @@ function form_filefield($attrs) {
  * $attrs['value'][1] is constructed as well.
  *
  * @author  Tom N Harris <tnharris@whoopdedo.org>
+ *
+ * @param array $attrs attributes
+ * @return string html
  */
 function form_checkboxfield($attrs) {
     // mandatory attributes
@@ -834,11 +992,11 @@ function form_checkboxfield($attrs) {
     if (!empty($attrs['id'])) $s .= ' for="'.$attrs['id'].'"';
     $s .= '>';
     if (is_array($attrs['value'])) {
-        echo '<input type="hidden" name="' . hsc($attrs['name']) .'"'
-                 . ' value="' . hsc($attrs['value'][1]) . '" />';
+        echo '<input type="hidden" name="'. hsc($attrs['name']) .'"'
+                .' value="'. hsc($attrs['value'][1]) .'" />';
         $attrs['value'] = $attrs['value'][0];
     }
-    $s .= '<input type="checkbox" '.buildAttributes($attrs,true).' />';
+    $s .= '<input type="checkbox" '. buildAttributes($attrs,true) .' />';
     $s .= ' <span>'.$attrs['_text'].'</span></label>';
     if (preg_match('/(^| )block($| )/', $attrs['_class']))
         $s .= '<br />';
@@ -854,6 +1012,9 @@ function form_checkboxfield($attrs) {
  * Other attributes are passed to buildAttributes() for the input tag.
  *
  * @author  Tom N Harris <tnharris@whoopdedo.org>
+ *
+ * @param array $attrs attributes
+ * @return string html
  */
 function form_radiofield($attrs) {
     // mandatory attributes
@@ -861,7 +1022,7 @@ function form_radiofield($attrs) {
     $s = '<label';
     if ($attrs['_class']) $s .= ' class="'.$attrs['_class'].'"';
     if (!empty($attrs['id'])) $s .= ' for="'.$attrs['id'].'"';
-    $s .= '><input type="radio" '.buildAttributes($attrs,true).' />';
+    $s .= '><input type="radio" '. buildAttributes($attrs,true) .' />';
     $s .= ' <span>'.$attrs['_text'].'</span></label>';
     if (preg_match('/(^| )block($| )/', $attrs['_class']))
         $s .= '<br />';
@@ -880,6 +1041,9 @@ function form_radiofield($attrs) {
  * Other attributes are passed to buildAttributes() for the input tag.
  *
  * @author  Tom N Harris <tnharris@whoopdedo.org>
+ *
+ * @param array $attrs attributes
+ * @return string html
  */
 function form_menufield($attrs) {
     $attrs['size'] = '1';
@@ -887,7 +1051,7 @@ function form_menufield($attrs) {
     if ($attrs['_class']) $s .= ' class="'.$attrs['_class'].'"';
     if (!empty($attrs['id'])) $s .= ' for="'.$attrs['id'].'"';
     $s .= '><span>'.$attrs['_text'].'</span>';
-    $s .= ' <select '.buildAttributes($attrs,true).'>'.DOKU_LF;
+    $s .= ' <select '. buildAttributes($attrs,true) .'>'.DOKU_LF;
     if (!empty($attrs['_options'])) {
         $selected = false;
 
@@ -896,14 +1060,14 @@ function form_menufield($attrs) {
             @list($value,$text,$select) = $attrs['_options'][$n];
             $p = '';
             if (!is_null($text))
-                $p .= ' value="'.formText($value).'"';
+                $p .= ' value="'. formText($value) .'"';
             else
                 $text = $value;
             if (!empty($select) && !$selected) {
                 $p .= ' selected="selected"';
                 $selected = true;
             }
-            $s .= '<option'.$p.'>'.formText($text).'</option>';
+            $s .= '<option'.$p.'>'. formText($text) .'</option>';
         }
     } else {
         $s .= '<option></option>';
@@ -925,21 +1089,25 @@ function form_menufield($attrs) {
  * Other attributes are passed to buildAttributes() for the input tag.
  *
  * @author  Tom N Harris <tnharris@whoopdedo.org>
+ *
+ * @param array $attrs attributes
+ * @return string html
  */
 function form_listboxfield($attrs) {
     $s = '<label';
     if ($attrs['_class']) $s .= ' class="'.$attrs['_class'].'"';
     if (!empty($attrs['id'])) $s .= ' for="'.$attrs['id'].'"';
     $s .= '><span>'.$attrs['_text'].'</span> ';
-    $s .= '<select '.buildAttributes($attrs,true).'>'.DOKU_LF;
+    $s .= '<select '. buildAttributes($attrs,true) .'>'.DOKU_LF;
     if (!empty($attrs['_options'])) {
         foreach ($attrs['_options'] as $opt) {
-            @list($value,$text,$select) = $opt;
+            @list($value, $text, $select, $disabled) = $opt;
             $p = '';
-            if(is_null($text)) $text = $value;
-            $p .= ' value="'.formText($value).'"';
+            if (is_null($text)) $text = $value;
+            $p .= ' value="'. formText($value) .'"';
             if (!empty($select)) $p .= ' selected="selected"';
-            $s .= '<option'.$p.'>'.formText($text).'</option>';
+            if ($disabled) $p .= ' disabled="disabled"';
+            $s .= '<option'.$p.'>'. formText($text) .'</option>';
         }
     } else {
         $s .= '<option></option>';
