@@ -3,8 +3,15 @@
  * Initialize some defaults needed for DokuWiki
  */
 
+use dokuwiki\Extension\Event;
+use dokuwiki\Extension\EventHandler;
+
 /**
  * timing Dokuwiki execution
+ *
+ * @param integer $start
+ *
+ * @return mixed
  */
 function delta_time($start=0) {
     return microtime(true)-((float)$start);
@@ -16,7 +23,7 @@ $config_cascade = array();
 
 // if available load a preload config file
 $preload = fullpath(dirname(__FILE__)).'/preload.php';
-if (@file_exists($preload)) include($preload);
+if (file_exists($preload)) include($preload);
 
 // define the include path
 if(!defined('DOKU_INC')) define('DOKU_INC',fullpath(dirname(__FILE__).'/../').'/');
@@ -28,19 +35,18 @@ if(!defined('DOKU_PLUGIN'))  define('DOKU_PLUGIN',DOKU_INC.'lib/plugins/');
 if(!defined('DOKU_CONF')) define('DOKU_CONF',DOKU_INC.'conf/');
 
 // check for error reporting override or set error reporting to sane values
-if (!defined('DOKU_E_LEVEL') && @file_exists(DOKU_CONF.'report_e_all')) {
+if (!defined('DOKU_E_LEVEL') && file_exists(DOKU_CONF.'report_e_all')) {
     define('DOKU_E_LEVEL', E_ALL);
 }
 if (!defined('DOKU_E_LEVEL')) {
-    if(defined('E_DEPRECATED')){ // since php 5.3, since php 5.4 E_STRICT is part of E_ALL
-        error_reporting(E_ALL & ~E_NOTICE & ~E_DEPRECATED & ~E_STRICT);
-    }else{
-        error_reporting(E_ALL ^ E_NOTICE);
-    }
+    error_reporting(E_ALL & ~E_NOTICE & ~E_DEPRECATED & ~E_STRICT);
 } else {
     error_reporting(DOKU_E_LEVEL);
 }
 
+// avoid caching issues #1594
+header('Vary: Cookie');
+
 // init memory caches
 global $cache_revinfo;
        $cache_revinfo = array();
@@ -65,7 +71,7 @@ $conf = array();
 foreach (array('default','local','protected') as $config_group) {
     if (empty($config_cascade['main'][$config_group])) continue;
     foreach ($config_cascade['main'][$config_group] as $config_file) {
-        if (@file_exists($config_file)) {
+        if (file_exists($config_file)) {
             include($config_file);
         }
     }
@@ -79,7 +85,7 @@ $license = array();
 foreach (array('default','local') as $config_group) {
     if (empty($config_cascade['license'][$config_group])) continue;
     foreach ($config_cascade['license'][$config_group] as $config_file) {
-        if(@file_exists($config_file)){
+        if(file_exists($config_file)){
             include($config_file);
         }
     }
@@ -100,23 +106,35 @@ if(!defined('DOKU_BASE')){
 }
 
 // define whitespace
+if(!defined('NL')) define ('NL',"\n");
 if(!defined('DOKU_LF')) define ('DOKU_LF',"\n");
 if(!defined('DOKU_TAB')) define ('DOKU_TAB',"\t");
 
 // define cookie and session id, append server port when securecookie is configured FS#1664
-if (!defined('DOKU_COOKIE')) define('DOKU_COOKIE', 'DW'.md5(DOKU_REL.(($conf['securecookie'])?$_SERVER['SERVER_PORT']:'')));
-
+if (!defined('DOKU_COOKIE')) {
+    $serverPort = isset($_SERVER['SERVER_PORT']) ? $_SERVER['SERVER_PORT'] : '';
+    define('DOKU_COOKIE', 'DW' . md5(DOKU_REL . (($conf['securecookie']) ? $serverPort : '')));
+    unset($serverPort);
+}
 
 // define main script
 if(!defined('DOKU_SCRIPT')) define('DOKU_SCRIPT','doku.php');
 
-// DEPRECATED, use tpl_basedir() instead
-if(!defined('DOKU_TPL')) define('DOKU_TPL',
-        DOKU_BASE.'lib/tpl/'.$conf['template'].'/');
+if(!defined('DOKU_TPL')) {
+    /**
+     * @deprecated 2012-10-13 replaced by more dynamic method
+     * @see tpl_basedir()
+     */
+    define('DOKU_TPL', DOKU_BASE.'lib/tpl/'.$conf['template'].'/');
+}
 
-// DEPRECATED, use tpl_incdir() instead
-if(!defined('DOKU_TPLINC')) define('DOKU_TPLINC',
-        DOKU_INC.'lib/tpl/'.$conf['template'].'/');
+if(!defined('DOKU_TPLINC')) {
+    /**
+     * @deprecated 2012-10-13 replaced by more dynamic method
+     * @see tpl_incdir()
+     */
+    define('DOKU_TPLINC', DOKU_INC.'lib/tpl/'.$conf['template'].'/');
+}
 
 // make session rewrites XHTML compliant
 @ini_set('arg_separator.output', '&amp;');
@@ -128,7 +146,8 @@ if(!defined('DOKU_TPLINC')) define('DOKU_TPLINC',
 @ini_set('pcre.backtrack_limit', '20971520');
 
 // enable gzip compression if supported
-$conf['gzip_output'] &= (strpos($_SERVER['HTTP_ACCEPT_ENCODING'],'gzip') !== false);
+$httpAcceptEncoding = isset($_SERVER['HTTP_ACCEPT_ENCODING']) ? $_SERVER['HTTP_ACCEPT_ENCODING'] : '';
+$conf['gzip_output'] &= (strpos($httpAcceptEncoding, 'gzip') !== false);
 global $ACT;
 if ($conf['gzip_output'] &&
         !defined('DOKU_DISABLE_GZIP_OUTPUT') &&
@@ -140,53 +159,30 @@ if ($conf['gzip_output'] &&
 }
 
 // init session
-if (!headers_sent() && !defined('NOSESSION')){
-    session_name("DokuWiki");
-    $cookieDir = empty($conf['cookiedir']) ? DOKU_REL : $conf['cookiedir'];
-    if (version_compare(PHP_VERSION, '5.2.0', '>')) {
-        session_set_cookie_params(0,$cookieDir,'',($conf['securecookie'] && is_ssl()),true);
-    }else{
-        session_set_cookie_params(0,$cookieDir,'',($conf['securecookie'] && is_ssl()));
+if(!headers_sent() && !defined('NOSESSION')) {
+    if(!defined('DOKU_SESSION_NAME'))     define ('DOKU_SESSION_NAME', "DokuWiki");
+    if(!defined('DOKU_SESSION_LIFETIME')) define ('DOKU_SESSION_LIFETIME', 0);
+    if(!defined('DOKU_SESSION_PATH')) {
+        $cookieDir = empty($conf['cookiedir']) ? DOKU_REL : $conf['cookiedir'];
+        define ('DOKU_SESSION_PATH', $cookieDir);
     }
-    session_start();
+    if(!defined('DOKU_SESSION_DOMAIN'))   define ('DOKU_SESSION_DOMAIN', '');
+
+    // start the session
+    init_session();
 
     // load left over messages
-    if(isset($_SESSION[DOKU_COOKIE]['msg'])){
+    if(isset($_SESSION[DOKU_COOKIE]['msg'])) {
         $MSG = $_SESSION[DOKU_COOKIE]['msg'];
         unset($_SESSION[DOKU_COOKIE]['msg']);
     }
 }
 
-// kill magic quotes
-if (get_magic_quotes_gpc() && !defined('MAGIC_QUOTES_STRIPPED')) {
-    if (!empty($_GET))    remove_magic_quotes($_GET);
-    if (!empty($_POST))   remove_magic_quotes($_POST);
-    if (!empty($_COOKIE)) remove_magic_quotes($_COOKIE);
-    if (!empty($_REQUEST)) remove_magic_quotes($_REQUEST);
-    @ini_set('magic_quotes_gpc', 0);
-    define('MAGIC_QUOTES_STRIPPED',1);
-}
-if(function_exists('set_magic_quotes_runtime')) @set_magic_quotes_runtime(0);
-@ini_set('magic_quotes_sybase',0);
-
 // don't let cookies ever interfere with request vars
 $_REQUEST = array_merge($_GET,$_POST);
 
 // we don't want a purge URL to be digged
-if(isset($_REQUEST['purge']) && $_SERVER['HTTP_REFERER']) unset($_REQUEST['purge']);
-
-// disable gzip if not available
-if($conf['compression'] == 'bz2' && !function_exists('bzopen')){
-    $conf['compression'] = 'gz';
-}
-if($conf['compression'] == 'gz' && !function_exists('gzopen')){
-    $conf['compression'] = 0;
-}
-
-// fix dateformat for upgraders
-if(strpos($conf['dformat'],'%') === false){
-    $conf['dformat'] = '%Y/%m/%d %H:%M';
-}
+if(isset($_REQUEST['purge']) && !empty($_SERVER['HTTP_REFERER'])) unset($_REQUEST['purge']);
 
 // precalculate file creation modes
 init_creationmodes();
@@ -196,26 +192,39 @@ init_paths();
 init_files();
 
 // setup plugin controller class (can be overwritten in preload.php)
-$plugin_types = array('auth', 'admin','syntax','action','renderer', 'helper','remote');
 global $plugin_controller_class, $plugin_controller;
-if (empty($plugin_controller_class)) $plugin_controller_class = 'Doku_Plugin_Controller';
+if (empty($plugin_controller_class)) $plugin_controller_class = dokuwiki\Extension\PluginController::class;
 
 // load libraries
+require_once(DOKU_INC.'vendor/autoload.php');
 require_once(DOKU_INC.'inc/load.php');
 
+// from now on everything is an exception
+\dokuwiki\ErrorHandler::register();
+
+// disable gzip if not available
+define('DOKU_HAS_BZIP', function_exists('bzopen'));
+define('DOKU_HAS_GZIP', function_exists('gzopen'));
+if($conf['compression'] == 'bz2' && !DOKU_HAS_BZIP) {
+    $conf['compression'] = 'gz';
+}
+if($conf['compression'] == 'gz' && !DOKU_HAS_GZIP) {
+    $conf['compression'] = 0;
+}
+
 // input handle class
 global $INPUT;
-$INPUT = new Input();
+$INPUT = new \dokuwiki\Input\Input();
 
 // initialize plugin controller
 $plugin_controller = new $plugin_controller_class();
 
 // initialize the event handler
 global $EVENT_HANDLER;
-$EVENT_HANDLER = new Doku_Event_Handler();
+$EVENT_HANDLER = new EventHandler();
 
 $local = $conf['lang'];
-trigger_event('INIT_LANG_LOAD', $local, 'init_lang', true);
+Event::createAndTrigger('INIT_LANG_LOAD', $local, 'init_lang', true);
 
 
 // setup authentication system
@@ -226,22 +235,56 @@ if (!defined('NOSESSION')) {
 // setup mail system
 mail_setup();
 
+$nil = null;
+Event::createAndTrigger('DOKUWIKI_INIT_DONE', $nil, null, false);
+
+/**
+ * Initializes the session
+ *
+ * Makes sure the passed session cookie is valid, invalid ones are ignored an a new session ID is issued
+ *
+ * @link http://stackoverflow.com/a/33024310/172068
+ * @link http://php.net/manual/en/session.configuration.php#ini.session.sid-length
+ */
+function init_session() {
+    global $conf;
+    session_name(DOKU_SESSION_NAME);
+    session_set_cookie_params(
+        DOKU_SESSION_LIFETIME,
+        DOKU_SESSION_PATH,
+        DOKU_SESSION_DOMAIN,
+        ($conf['securecookie'] && is_ssl()),
+        true
+    );
+
+    // make sure the session cookie contains a valid session ID
+    if(isset($_COOKIE[DOKU_SESSION_NAME]) && !preg_match('/^[-,a-zA-Z0-9]{22,256}$/', $_COOKIE[DOKU_SESSION_NAME])) {
+        unset($_COOKIE[DOKU_SESSION_NAME]);
+    }
+
+    session_start();
+}
+
+
 /**
  * Checks paths from config file
  */
 function init_paths(){
     global $conf;
 
-    $paths = array('datadir'   => 'pages',
-            'olddir'    => 'attic',
-            'mediadir'  => 'media',
-            'mediaolddir' => 'media_attic',
-            'metadir'   => 'meta',
-            'mediametadir' => 'media_meta',
-            'cachedir'  => 'cache',
-            'indexdir'  => 'index',
-            'lockdir'   => 'locks',
-            'tmpdir'    => 'tmp');
+    $paths = [
+        'datadir'   => 'pages',
+        'olddir'    => 'attic',
+        'mediadir'  => 'media',
+        'mediaolddir' => 'media_attic',
+        'metadir'   => 'meta',
+        'mediametadir' => 'media_meta',
+        'cachedir'  => 'cache',
+        'indexdir'  => 'index',
+        'lockdir'   => 'locks',
+        'tmpdir'    => 'tmp',
+        'logdir'    => 'log',
+    ];
 
     foreach($paths as $c => $p) {
         $path = empty($conf[$c]) ? $conf['savedir'].'/'.$p : $conf[$c];
@@ -254,23 +297,41 @@ function init_paths(){
     }
 
     // path to old changelog only needed for upgrading
-    $conf['changelog_old'] = init_path((isset($conf['changelog']))?($conf['changelog']):($conf['savedir'].'/changes.log'));
+    $conf['changelog_old'] = init_path(
+        (isset($conf['changelog'])) ? ($conf['changelog']) : ($conf['savedir'] . '/changes.log')
+    );
     if ($conf['changelog_old']=='') { unset($conf['changelog_old']); }
     // hardcoded changelog because it is now a cache that lives in meta
     $conf['changelog'] = $conf['metadir'].'/_dokuwiki.changes';
     $conf['media_changelog'] = $conf['metadir'].'/_media.changes';
 }
 
+/**
+ * Load the language strings
+ *
+ * @param string $langCode language code, as passed by event handler
+ */
 function init_lang($langCode) {
     //prepare language array
-    global $lang;
+    global $lang, $config_cascade;
     $lang = array();
 
     //load the language files
-    require_once(DOKU_INC.'inc/lang/en/lang.php');
+    require(DOKU_INC.'inc/lang/en/lang.php');
+    foreach ($config_cascade['lang']['core'] as $config_file) {
+        if (file_exists($config_file . 'en/lang.php')) {
+            include($config_file . 'en/lang.php');
+        }
+    }
+
     if ($langCode && $langCode != 'en') {
         if (file_exists(DOKU_INC."inc/lang/$langCode/lang.php")) {
-            require_once(DOKU_INC."inc/lang/$langCode/lang.php");
+            require(DOKU_INC."inc/lang/$langCode/lang.php");
+        }
+        foreach ($config_cascade['lang']['core'] as $config_file) {
+            if (file_exists($config_file . "$langCode/lang.php")) {
+                include($config_file . "$langCode/lang.php");
+            }
         }
     }
 }
@@ -284,7 +345,7 @@ function init_files(){
     $files = array($conf['indexdir'].'/page.idx');
 
     foreach($files as $file){
-        if(!@file_exists($file)){
+        if(!file_exists($file)){
             $fh = @fopen($file,'a');
             if($fh){
                 fclose($fh);
@@ -294,24 +355,6 @@ function init_files(){
             }
         }
     }
-
-    # create title index (needs to have same length as page.idx)
-    /*
-    $file = $conf['indexdir'].'/title.idx';
-    if(!@file_exists($file)){
-        $pages = file($conf['indexdir'].'/page.idx');
-        $pages = count($pages);
-        $fh = @fopen($file,'a');
-        if($fh){
-            for($i=0; $i<$pages; $i++){
-                fwrite($fh,"\n");
-            }
-            fclose($fh);
-        }else{
-            nice_die("$file is not writable. Check your permissions settings!");
-        }
-    }
-    */
 }
 
 /**
@@ -321,13 +364,17 @@ function init_files(){
  * Check for accessibility on directories as well.
  *
  * @author Andreas Gohr <andi@splitbrain.org>
+ *
+ * @param string $path
+ *
+ * @return bool|string
  */
 function init_path($path){
     // check existence
     $p = fullpath($path);
-    if(!@file_exists($p)){
+    if(!file_exists($p)){
         $p = fullpath(DOKU_INC.$path);
-        if(!@file_exists($p)){
+        if(!file_exists($p)){
             return '';
         }
     }
@@ -338,7 +385,7 @@ function init_path($path){
     }
 
     // check accessability (execute bit) for directories
-    if(@is_dir($p) && !@file_exists("$p/.")){
+    if(@is_dir($p) && !file_exists("$p/.")){
         return '';
     }
 
@@ -358,8 +405,9 @@ function init_creationmodes(){
     unset($conf['dmask']);
     unset($conf['fmask']);
     unset($conf['umask']);
-    unset($conf['fperm']);
-    unset($conf['dperm']);
+
+    $conf['fperm'] = false;
+    $conf['dperm'] = false;
 
     // get system umask, fallback to 0 if none available
     $umask = @umask();
@@ -370,48 +418,32 @@ function init_creationmodes(){
     $auto_fmode = 0666 & ~$umask;
     if($auto_fmode != $conf['fmode']) $conf['fperm'] = $conf['fmode'];
 
-    // check what is set automatically by the system on file creation
-    // and set the dperm param if it's not what we want
-    $auto_dmode = $conf['dmode'] & ~$umask;
+    // check what is set automatically by the system on directory creation
+    // and set the dperm param if it's not what we want.
+    $auto_dmode = 0777 & ~$umask;
     if($auto_dmode != $conf['dmode']) $conf['dperm'] = $conf['dmode'];
 }
 
-/**
- * remove magic quotes recursivly
- *
- * @author Andreas Gohr <andi@splitbrain.org>
- */
-function remove_magic_quotes(&$array) {
-    foreach (array_keys($array) as $key) {
-        // handle magic quotes in keynames (breaks order)
-        $sk = stripslashes($key);
-        if($sk != $key){
-            $array[$sk] = $array[$key];
-            unset($array[$key]);
-            $key = $sk;
-        }
-
-        // do recursion if needed
-        if (is_array($array[$key])) {
-            remove_magic_quotes($array[$key]);
-        }else {
-            $array[$key] = stripslashes($array[$key]);
-        }
-    }
-}
-
 /**
  * Returns the full absolute URL to the directory where
  * DokuWiki is installed in (includes a trailing slash)
  *
+ * !! Can not access $_SERVER values through $INPUT
+ * !! here as this function is called before $INPUT is
+ * !! initialized.
+ *
  * @author Andreas Gohr <andi@splitbrain.org>
+ *
+ * @param null|string $abs
+ *
+ * @return string
  */
 function getBaseURL($abs=null){
     global $conf;
     //if canonical url enabled always return absolute
     if(is_null($abs)) $abs = $conf['canonical'];
 
-    if($conf['basedir']){
+    if(!empty($conf['basedir'])){
         $dir = $conf['basedir'];
     }elseif(substr($_SERVER['SCRIPT_NAME'],-4) == '.php'){
         $dir = dirname($_SERVER['SCRIPT_NAME']);
@@ -437,27 +469,23 @@ function getBaseURL($abs=null){
     //finish here for relative URLs
     if(!$abs) return $dir;
 
-    //use config option if available, trim any slash from end of baseurl to avoid multiple consecutive slashes in the path
-    if($conf['baseurl']) return rtrim($conf['baseurl'],'/').$dir;
+    //use config if available, trim any slash from end of baseurl to avoid multiple consecutive slashes in the path
+    if(!empty($conf['baseurl'])) return rtrim($conf['baseurl'],'/').$dir;
 
     //split hostheader into host and port
     if(isset($_SERVER['HTTP_HOST'])){
         $parsed_host = parse_url('http://'.$_SERVER['HTTP_HOST']);
-        $host = $parsed_host['host'];
-        $port = $parsed_host['port'];
+        $host = isset($parsed_host['host']) ? $parsed_host['host'] : null;
+        $port = isset($parsed_host['port']) ? $parsed_host['port'] : null;
     }elseif(isset($_SERVER['SERVER_NAME'])){
         $parsed_host = parse_url('http://'.$_SERVER['SERVER_NAME']);
-        $host = $parsed_host['host'];
-        $port = $parsed_host['port'];
+        $host = isset($parsed_host['host']) ? $parsed_host['host'] : null;
+        $port = isset($parsed_host['port']) ? $parsed_host['port'] : null;
     }else{
         $host = php_uname('n');
         $port = '';
     }
 
-    if(!$port && isset($_SERVER['SERVER_PORT'])) {
-        $port = $_SERVER['SERVER_PORT'];
-    }
-
     if(is_null($port)){
         $port = '';
     }
@@ -487,17 +515,35 @@ function getBaseURL($abs=null){
  *
  * @returns bool true when SSL is active
  */
-function is_ssl(){
-    if (!isset($_SERVER['HTTPS']) ||
-        preg_match('/^(|off|false|disabled)$/i',$_SERVER['HTTPS'])){
+function is_ssl() {
+    // check if we are behind a reverse proxy
+    if(isset($_SERVER['HTTP_X_FORWARDED_PROTO'])) {
+        if($_SERVER['HTTP_X_FORWARDED_PROTO'] == 'https') {
+            return true;
+        } else {
+            return false;
+        }
+    }
+    if(!isset($_SERVER['HTTPS']) ||
+        preg_match('/^(|off|false|disabled)$/i', $_SERVER['HTTPS'])) {
         return false;
-    }else{
+    } else {
         return true;
     }
 }
 
+/**
+ * checks it is windows OS
+ * @return bool
+ */
+function isWindows() {
+    return (strtoupper(substr(PHP_OS, 0, 3)) === 'WIN') ? true : false;
+}
+
 /**
  * print a nice message even if no styles are loaded yet.
+ *
+ * @param integer|string $msg
  */
 function nice_die($msg){
     echo<<<EOT
@@ -513,7 +559,10 @@ function nice_die($msg){
 </body>
 </html>
 EOT;
-    exit;
+    if(defined('DOKU_UNITTEST')) {
+        throw new RuntimeException('nice_die: '.$msg);
+    }
+    exit(1);
 }
 
 /**
@@ -524,15 +573,20 @@ EOT;
  *
  * @author Andreas Gohr <andi@splitbrain.org>
  * @author <richpageau at yahoo dot co dot uk>
- * @link   http://de3.php.net/manual/en/function.realpath.php#75992
+ * @link   http://php.net/manual/en/function.realpath.php#75992
+ *
+ * @param string $path
+ * @param bool $exists
+ *
+ * @return bool|string
  */
 function fullpath($path,$exists=false){
     static $run = 0;
     $root  = '';
-    $iswin = (strtoupper(substr(PHP_OS, 0, 3)) === 'WIN' || @$GLOBALS['DOKU_UNITTEST_ASSUME_WINDOWS']);
+    $iswin = (strtoupper(substr(PHP_OS, 0, 3)) === 'WIN' || !empty($GLOBALS['DOKU_UNITTEST_ASSUME_WINDOWS']));
 
     // find the (indestructable) root of the path - keeps windows stuff intact
-    if($path{0} == '/'){
+    if($path[0] == '/'){
         $root = '/';
     }elseif($iswin){
         // match drive letter and UNC paths
@@ -571,7 +625,7 @@ function fullpath($path,$exists=false){
     $finalpath = $root.implode('/', $newpath);
 
     // check for existence when needed (except when unit testing)
-    if($exists && !defined('DOKU_UNITTEST') && !@file_exists($finalpath)) {
+    if($exists && !defined('DOKU_UNITTEST') && !file_exists($finalpath)) {
         return false;
     }
     return $finalpath;
