@@ -27,19 +27,18 @@ $lang['btn_top']               = 'Back to top';
 $lang['btn_newer']             = '<< more recent';
 $lang['btn_older']             = 'less recent >>';
 $lang['btn_revs']              = 'Old revisions';
-$lang['btn_recent']            = 'Recent changes';
+$lang['btn_recent']            = 'Recent Changes';
 $lang['btn_upload']            = 'Upload';
 $lang['btn_cancel']            = 'Cancel';
 $lang['btn_index']             = 'Sitemap';
 $lang['btn_secedit']           = 'Edit';
-$lang['btn_login']             = 'Login';
-$lang['btn_logout']            = 'Logout';
+$lang['btn_login']             = 'Log In';
+$lang['btn_logout']            = 'Log Out';
 $lang['btn_admin']             = 'Admin';
 $lang['btn_update']            = 'Update';
 $lang['btn_delete']            = 'Delete';
 $lang['btn_back']              = 'Back';
 $lang['btn_backlink']          = 'Backlinks';
-$lang['btn_backtomedia']       = 'Back to Mediafile Selection';
 $lang['btn_subscribe']         = 'Manage Subscriptions';
 $lang['btn_profile']           = 'Update Profile';
 $lang['btn_reset']             = 'Reset';
@@ -51,8 +50,11 @@ $lang['btn_revert']            = 'Restore';
 $lang['btn_register']          = 'Register';
 $lang['btn_apply']             = 'Apply';
 $lang['btn_media']             = 'Media Manager';
+$lang['btn_deleteuser']        = 'Remove My Account';
+$lang['btn_img_backto']        = 'Back to %s';
+$lang['btn_mediaManager']      = 'View in media manager';
 
-$lang['loggedinas']            = 'Logged in as';
+$lang['loggedinas']            = 'Logged in as:';
 $lang['user']                  = 'Username';
 $lang['pass']                  = 'Password';
 $lang['newpass']               = 'New password';
@@ -63,14 +65,32 @@ $lang['fullname']              = 'Real name';
 $lang['email']                 = 'E-Mail';
 $lang['profile']               = 'User Profile';
 $lang['badlogin']              = 'Sorry, username or password was wrong.';
+$lang['badpassconfirm']        = 'Sorry, the password was wrong';
 $lang['minoredit']             = 'Minor Changes';
 $lang['draftdate']             = 'Draft autosaved on'; // full dformat date will be added
 $lang['nosecedit']             = 'The page was changed in the meantime, section info was out of date loaded full page instead.';
+$lang['searchcreatepage']      = 'If you didn\'t find what you were looking for, you can create or edit the page %s, named after your query.';
+
+$lang['search_fullresults']    = 'Fulltext results';
+$lang['js']['search_toggle_tools']   = 'Toggle Search Tools';
+$lang['search_exact_match']    = 'Exact match';
+$lang['search_starts_with']    = 'Starts with';
+$lang['search_ends_with']      = 'Ends with';
+$lang['search_contains']       = 'Contains';
+$lang['search_custom_match']   = 'Custom';
+$lang['search_any_ns']         = 'Any namespace';
+$lang['search_any_time']       = 'Any time';
+$lang['search_past_7_days']    = 'Past week';
+$lang['search_past_month']     = 'Past month';
+$lang['search_past_year']      = 'Past year';
+$lang['search_sort_by_hits']   = 'Sort by hits';
+$lang['search_sort_by_mtime']  = 'Sort by last modified';
 
 $lang['regmissing']            = 'Sorry, you must fill in all fields.';
 $lang['reguexists']            = 'Sorry, a user with this login already exists.';
 $lang['regsuccess']            = 'The user has been created and the password was sent by email.';
 $lang['regsuccess2']           = 'The user has been created.';
+$lang['regfail']               = 'The user could not be created.';
 $lang['regmailfail']           = 'Looks like there was an error on sending the password mail. Please contact the admin!';
 $lang['regbadmail']            = 'The given email address looks invalid - if you think this is an error, contact the admin';
 $lang['regbadpass']            = 'The two given passwords are not identical, please try again.';
@@ -81,6 +101,12 @@ $lang['profna']                = 'This wiki does not support profile modificatio
 $lang['profnochange']          = 'No changes, nothing to do.';
 $lang['profnoempty']           = 'An empty name or email address is not allowed.';
 $lang['profchanged']           = 'User profile successfully updated.';
+$lang['profnodelete']          = 'This wiki does not support deleting users';
+$lang['profdeleteuser']        = 'Delete Account';
+$lang['profdeleted']           = 'Your user account has been deleted from this wiki';
+$lang['profconfdelete']        = 'I wish to remove my account from this wiki. <br/> This action can not be undone.';
+$lang['profconfdeletemissing'] = 'Confirmation check box not ticked';
+$lang['proffail']              = 'User profile was not updated.';
 
 $lang['pwdforget']             = 'Forgotten your password? Get a new one';
 $lang['resendna']              = 'This wiki does not support password resending.';
@@ -96,12 +122,13 @@ $lang['licenseok']             = 'Note: By editing this page you agree to licens
 
 $lang['searchmedia']           = 'Search file name:';
 $lang['searchmedia_in']        = 'Search in %s';
-$lang['txt_upload']            = 'Select file to upload';
-$lang['txt_filename']          = 'Upload as (optional)';
+$lang['txt_upload']            = 'Select file to upload:';
+$lang['txt_filename']          = 'Upload as (optional):';
 $lang['txt_overwrt']           = 'Overwrite existing file';
 $lang['maxuploadsize']         = 'Upload max. %s per file.';
-$lang['lockedby']              = 'Currently locked by';
-$lang['lockexpire']            = 'Lock expires at';
+$lang['allowedmime']           = 'List of allowed file extensions';
+$lang['lockedby']              = 'Currently locked by:';
+$lang['lockexpire']            = 'Lock expires at:';
 
 $lang['js']['willexpire']      = 'Your lock for editing this page is about to expire in a minute.\nTo avoid conflicts use the preview button to reset the locktimer.';
 $lang['js']['notsavedyet']     = 'Unsaved changes will be lost.';
@@ -144,12 +171,12 @@ $lang['js']['media_done_btn']      = 'Done';
 $lang['js']['media_drop']          = 'Drop files here to upload';
 $lang['js']['media_cancel']        = 'remove';
 $lang['js']['media_overwrt']       = 'Overwrite existing files';
+$lang['js']['data_insecure'] = 'WARNING: It seems your data directory is not properly secured. Please read about <a href="https://www.dokuwiki.org/security#web_access_security">Web Access Security in DokuWiki</a>.';
 
 $lang['rssfailed']             = 'An error occurred while fetching this feed: ';
 $lang['nothingfound']          = 'Nothing was found.';
 
 $lang['mediaselect']           = 'Media Files';
-$lang['fileupload']            = 'Media File Upload';
 $lang['uploadsucc']            = 'Upload successful';
 $lang['uploadfail']            = 'Upload failed. Maybe wrong permissions?';
 $lang['uploadwrong']           = 'Upload denied. This file extension is forbidden!';
@@ -184,17 +211,23 @@ $lang['difflink']              = 'Link to this comparison view';
 $lang['diff_type']             = 'View differences:';
 $lang['diff_inline']           = 'Inline';
 $lang['diff_side']             = 'Side by Side';
+$lang['diffprevrev']           = 'Previous revision';
+$lang['diffnextrev']           = 'Next revision';
+$lang['difflastrev']           = 'Last revision';
+$lang['diffbothprevrev']       = 'Both sides previous revision';
+$lang['diffbothnextrev']       = 'Both sides next revision';
 $lang['line']                  = 'Line';
-$lang['breadcrumb']            = 'Trace';
-$lang['youarehere']            = 'You are here';
-$lang['lastmod']               = 'Last modified';
+$lang['breadcrumb']            = 'Trace:';
+$lang['youarehere']            = 'You are here:';
+$lang['lastmod']               = 'Last modified:';
 $lang['by']                    = 'by';
 $lang['deleted']               = 'removed';
 $lang['created']               = 'created';
 $lang['restored']              = 'old revision restored (%s)';
 $lang['external_edit']         = 'external edit';
 $lang['summary']               = 'Edit summary';
-$lang['noflash']               = 'The <a href="http://www.adobe.com/products/flashplayer/">Adobe Flash Plugin</a> is needed to display this content.';
+$lang['unknowndate']           = 'Unknown date';
+$lang['noflash']               = 'The <a href="http://get.adobe.com/flashplayer">Adobe Flash Plugin</a> is needed to display this content.';
 $lang['download']              = 'Download Snippet';
 $lang['tools']                 = 'Tools';
 $lang['user_tools']            = 'User Tools';
@@ -217,7 +250,7 @@ $lang['both_changes']          = 'Both pages and media files';
 $lang['qb_bold']               = 'Bold Text';
 $lang['qb_italic']             = 'Italic Text';
 $lang['qb_underl']             = 'Underlined Text';
-$lang['qb_code']               = 'Code Text';
+$lang['qb_code']               = 'Monospaced Text';
 $lang['qb_strike']             = 'Strike-through Text';
 $lang['qb_h1']                 = 'Level 1 Headline';
 $lang['qb_h2']                 = 'Level 2 Headline';
@@ -234,32 +267,28 @@ $lang['qb_extlink']            = 'External Link';
 $lang['qb_hr']                 = 'Horizontal Rule';
 $lang['qb_ol']                 = 'Ordered List Item';
 $lang['qb_ul']                 = 'Unordered List Item';
-$lang['qb_media']              = 'Add Images and other files';
+$lang['qb_media']              = 'Add Images and other files (opens in a new window)';
 $lang['qb_sig']                = 'Insert Signature';
 $lang['qb_smileys']            = 'Smileys';
 $lang['qb_chars']              = 'Special Chars';
 
 $lang['upperns']               = 'jump to parent namespace';
 
-$lang['admin_register']        = 'Add new user';
-
 $lang['metaedit']              = 'Edit Metadata';
 $lang['metasaveerr']           = 'Writing metadata failed';
 $lang['metasaveok']            = 'Metadata saved';
-$lang['img_backto']            = 'Back to';
-$lang['img_title']             = 'Title';
-$lang['img_caption']           = 'Caption';
-$lang['img_date']              = 'Date';
-$lang['img_fname']             = 'Filename';
-$lang['img_fsize']             = 'Size';
-$lang['img_artist']            = 'Photographer';
-$lang['img_copyr']             = 'Copyright';
-$lang['img_format']            = 'Format';
-$lang['img_camera']            = 'Camera';
-$lang['img_keywords']          = 'Keywords';
-$lang['img_width']             = 'Width';
-$lang['img_height']            = 'Height';
-$lang['img_manager']           = 'View in media manager';
+$lang['img_title']             = 'Title:';
+$lang['img_caption']           = 'Caption:';
+$lang['img_date']              = 'Date:';
+$lang['img_fname']             = 'Filename:';
+$lang['img_fsize']             = 'Size:';
+$lang['img_artist']            = 'Photographer:';
+$lang['img_copyr']             = 'Copyright:';
+$lang['img_format']            = 'Format:';
+$lang['img_camera']            = 'Camera:';
+$lang['img_keywords']          = 'Keywords:';
+$lang['img_width']             = 'Width:';
+$lang['img_height']            = 'Height:';
 
 $lang['subscr_subscribe_success']   = 'Added %s to subscription list for %s';
 $lang['subscr_subscribe_error']     = 'Error adding %s to subscription list for %s';
@@ -280,9 +309,7 @@ $lang['subscr_style_digest']        = 'digest email of changes for each page (ev
 $lang['subscr_style_list']          = 'list of changed pages since last email (every %.2f days)';
 
 /* auth.class language support */
-$lang['authmodfailed']         = 'Bad user authentication configuration. Please inform your Wiki Admin.';
 $lang['authtempfail']          = 'User authentication is temporarily unavailable. If this situation persists, please inform your Wiki Admin.';
-$lang['authpwdexpire']         = 'Your password will expire in %d days, you should change it soon.';
 
 /* installer strings */
 $lang['i_chooselang']          = 'Choose your language';
@@ -293,9 +320,14 @@ $lang['i_superuser']           = 'Superuser';
 $lang['i_problems']            = 'The installer found some problems, indicated below. You can not continue until you have fixed them.';
 $lang['i_modified']            = 'For security reasons this script will only work with a new and unmodified Dokuwiki installation.
                                   You should either re-extract the files from the downloaded package or consult the complete
-                                  <a href="http://dokuwiki.org/install">Dokuwiki installation instructions</a>';
+                                  <a href="https://www.dokuwiki.org/install">Dokuwiki installation instructions</a>';
 $lang['i_funcna']              = 'PHP function <code>%s</code> is not available. Maybe your hosting provider disabled it for some reason?';
+$lang['i_disabled']            =  'It has been disabled by your provider.';
+$lang['i_funcnmail']           = '<b>Note:</b> The PHP mail function is not available. %s' .
+                                 ' If it remains unavailable, you may install the <a href="https://www.dokuwiki.org/plugin:smtp">smtp plugin</a>.';
 $lang['i_phpver']              = 'Your PHP version <code>%s</code> is lower than the needed <code>%s</code>. You need to upgrade your PHP install.';
+$lang['i_mbfuncoverload']      = 'mbstring.func_overload must be disabled in php.ini to run DokuWiki.';
+$lang['i_urandom']             = 'DokuWiki cannot create cryptographically secure numbers for cookies. You may want to check your open_basedir settings in php.ini for proper <code>/dev/urandom</code> access.';
 $lang['i_permfail']            = '<code>%s</code> is not writable by DokuWiki. You need to fix the permission settings of this directory!';
 $lang['i_confexists']          = '<code>%s</code> already exists';
 $lang['i_writeerr']            = 'Unable to create <code>%s</code>. You will need to check directory/file permissions and create the file manually.';
@@ -309,6 +341,7 @@ $lang['i_policy']              = 'Initial ACL policy';
 $lang['i_pol0']                = 'Open Wiki (read, write, upload for everyone)';
 $lang['i_pol1']                = 'Public Wiki (read for everyone, write and upload for registered users)';
 $lang['i_pol2']                = 'Closed Wiki (read, write, upload for registered users only)';
+$lang['i_allowreg']            = 'Allow users to register themselves';
 $lang['i_retry']               = 'Retry';
 $lang['i_license']             = 'Please choose the license you want to put your content under:';
 $lang['i_license_none']        = 'Do not show any license information';
@@ -349,5 +382,16 @@ $lang['media_perm_read']       = 'Sorry, you don\'t have enough rights to read f
 $lang['media_perm_upload']     = 'Sorry, you don\'t have enough rights to upload files.';
 $lang['media_update']          = 'Upload new version';
 $lang['media_restore']         = 'Restore this version';
+$lang['media_acl_warning']     = 'This list might not be complete due to ACL restrictions and hidden pages.';
+
+$lang['email_fail']            = 'PHP mail() missing or disabled. The following email was not sent: ';
+$lang['currentns']             = 'Current namespace';
+$lang['searchresult']          = 'Search Result';
+$lang['plainhtml']             = 'Plain HTML';
+$lang['wikimarkup']            = 'Wiki Markup';
+$lang['page_nonexist_rev']     = 'Page did not exist at %s. It was subsequently created at <a href="%s">%s</a>.';
+$lang['unable_to_parse_date']  = 'Unable to parse at parameter "%s".';
+$lang['email_signature_text'] = 'This mail was generated by DokuWiki at
+@DOKUWIKIURL@';
+#$lang['email_signature_html'] = ''; # the empty default will copy the text signature, you can override it in a local lang file
 
-//Setup VIM: ex: et ts=2 :
