@@ -2,7 +2,15 @@
 
 /**
  * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
- * 
+ *
+ * @author Schplurtz le Déboulonné <schplurtz@laposte.net>
+ * @author Olivier Humbert <trebmuh@tuxfamily.org>
+ * @author Nicolas Friedli <nicolas@theologique.ch>
+ * @author Pierre Henriot <pierre.henriot@gmail.com>
+ * @author PaliPalo <palipalo@hotmail.fr>
+ * @author Laurent Ponthieu <contact@coopindus.fr>
+ * @author Damien Regad <dregad@mantisbt.org>
+ * @author Michael Bohn <mjbohn@gmail.com>
  * @author Sébastien Bauer <sebastien.bauer@advalvas.be>
  * @author Antoine Fixary <antoine.fixary@freesbee.fr>
  * @author cumulus <pta-n56@myamail.com>
@@ -12,7 +20,7 @@
  * @author Stéphane Chamberland <stephane.chamberland@ec.gc.ca>
  * @author Delassaux Julien <julien@delassaux.fr>
  * @author Maurice A. LeBlanc <leblancma@cooptel.qc.ca>
- * @author stephane.gully@gmail.com
+ * @author stephane.gully <stephane.gully@gmail.com>
  * @author Guillaume Turri <guillaume.turri@gmail.com>
  * @author Erik Pedersen <erik.pedersen@shaw.ca>
  * @author olivier duperray <duperray.olivier@laposte.net>
@@ -21,8 +29,6 @@
  * @author Florian Gaub <floriang@floriang.net>
  * @author Samuel Dorsaz <samuel.dorsaz@novelion.net>
  * @author Johan Guilbaud <guilbaud.johan@gmail.com>
- * @author schplurtz@laposte.net
- * @author skimpax@gmail.com
  * @author Yannick Aure <yannick.aure@gmail.com>
  * @author Olivier DUVAL <zorky00@gmail.com>
  * @author Anael Mobilia <contrib@anael.eu>
@@ -33,11 +39,11 @@
  * @author ggallon <gwenael.gallon@mac.com>
  * @author David VANTYGHEM <david.vantyghem@free.fr>
  * @author Caillot <remicaillot5@gmail.com>
- * @author Schplurtz le Déboulonné <schplurtz@laposte.net>
  * @author YoBoY <yoboy@ubuntu-fr.org>
  * @author james <j.mccann@celcat.com>
  * @author Pietroni <pietroni@informatique.univ-paris-diderot.fr>
  * @author Floriang <antispam@floriang.eu>
+ * @author Eric <ericstevenart@netc.fr>
  */
 $lang['encoding']              = 'utf-8';
 $lang['direction']             = 'ltr';
@@ -98,45 +104,9 @@ $lang['badpassconfirm']        = 'Désolé, le mot de passe est erroné';
 $lang['minoredit']             = 'Modification mineure';
 $lang['draftdate']             = 'Brouillon enregistré automatiquement le';
 $lang['nosecedit']             = 'La page a changé entre temps, les informations de la section sont obsolètes ; la page complète a été chargée à la place.';
-$lang['searchcreatepage']      = 'Si vous n\'avez pas trouvé ce que vous cherchiez, vous pouvez créer ou modifier la page correspondante à votre requête en cliquant sur le bouton approprié.';
-$lang['regmissing']            = 'Désolé, vous devez remplir tous les champs.';
-$lang['reguexists']            = 'Désolé, ce nom d\'utilisateur est déjà pris.';
-$lang['regsuccess']            = 'L\'utilisateur a été créé. Le mot de passe a été expédié par courriel.';
-$lang['regsuccess2']           = 'L\'utilisateur a été créé.';
-$lang['regfail']               = 'L\'utilisateur n\'a pu être crée.';
-$lang['regmailfail']           = 'On dirait qu\'il y a eu une erreur lors de l\'envoi du mot de passe de messagerie. Veuillez contacter l\'administrateur !';
-$lang['regbadmail']            = 'L\'adresse de courriel semble incorrecte. Si vous pensez que c\'est une erreur, contactez l\'administrateur.';
-$lang['regbadpass']            = 'Les deux mots de passe fournis sont différents, veuillez recommencez.';
-$lang['regpwmail']             = 'Votre mot de passe DokuWiki';
-$lang['reghere']               = 'Vous n\'avez pas encore de compte ? Inscrivez-vous';
-$lang['profna']                = 'Ce wiki ne permet pas de modifier les profils';
-$lang['profnochange']          = 'Pas de modification, rien à faire.';
-$lang['profnoempty']           = 'Un nom ou une adresse de courriel vide n\'est pas permis.';
-$lang['profchanged']           = 'Mise à jour du profil réussie.';
-$lang['profnodelete']          = 'Ce wiki ne permet pas la suppression des utilisateurs';
-$lang['profdeleteuser']        = 'Supprimer le compte';
-$lang['profdeleted']           = 'Votre compte utilisateur a été supprimé de ce wiki';
-$lang['profconfdelete']        = 'Je veux supprimer mon compte sur ce wiki. </br> Cette action est irréversible.';
-$lang['profconfdeletemissing'] = 'La case de confirmation n\'est pas cochée';
-$lang['proffail']              = 'Le profil utilisateur n\'a pas été mis à jour.';
-$lang['pwdforget']             = 'Mot de passe oublié ? Obtenez-en un nouveau';
-$lang['resendna']              = 'Ce wiki ne permet pas le renvoi de mot de passe.';
-$lang['resendpwd']             = 'Définir un nouveau mot de passe pour';
-$lang['resendpwdmissing']      = 'Désolé, vous devez remplir tous les champs.';
-$lang['resendpwdnouser']       = 'Désolé, cet utilisateur n\'existe pas dans notre base de données.';
-$lang['resendpwdbadauth']      = 'Désolé, ce code d\'authentification est invalide. Assurez-vous d\'avoir utilisé le lien de confirmation intégral.';
-$lang['resendpwdconfirm']      = 'Un lien de confirmation vous a été expédié par courriel.';
-$lang['resendpwdsuccess']      = 'Votre nouveau mot de passe vous a été expédié par courriel.';
-$lang['license']               = 'Sauf mention contraire, le contenu de ce wiki est placé sous les termes de la licence suivante :';
-$lang['licenseok']             = 'Note : En modifiant cette page, vous acceptez que le contenu soit placé sous les termes de la licence suivante :';
-$lang['searchmedia']           = 'Chercher le nom de fichier :';
-$lang['searchmedia_in']        = 'Chercher dans %s';
-$lang['txt_upload']            = 'Sélectionnez un fichier à envoyer:';
-$lang['txt_filename']          = 'Envoyer en tant que (optionnel):';
-$lang['txt_overwrt']           = 'Écraser le fichier cible (s\'il existe)';
-$lang['maxuploadsize']         = 'Taille d\'envoi maximale : %s par fichier';
-$lang['lockedby']              = 'Actuellement bloqué par:';
-$lang['lockexpire']            = 'Le blocage expire à:';
+$lang['searchcreatepage']      = 'Si vous ne trouvez pas ce que vous cherchiez, vous pouvez créer ou éditer la page %s, nommée selon les termes de votre recherche.';
+$lang['search_fullresults']    = 'Résultats plein texte';
+$lang['js']['search_toggle_tools'] = '(dé)activer les outils de recherche';
 $lang['js']['willexpire']      = 'Votre blocage pour la modification de cette page expire dans une minute.\nPour éviter les conflits, utilisez le bouton « Aperçu » pour réinitialiser le minuteur.';
 $lang['js']['notsavedyet']     = 'Les modifications non enregistrées seront perdues. Voulez-vous vraiment continuer ?';
 $lang['js']['searchmedia']     = 'Chercher des fichiers';
@@ -178,13 +148,65 @@ $lang['js']['media_done_btn']  = 'Terminé';
 $lang['js']['media_drop']      = 'Déposez des fichiers ici pour les envoyer';
 $lang['js']['media_cancel']    = 'supprimer';
 $lang['js']['media_overwrt']   = 'Écraser les fichiers existants';
+$lang['js']['data_insecure']   = 'ATTENTION : votre dossier de données ne semble pas correctement sécurisé. Veuillez lire <a href="https://www.dokuwiki.org/fr:security#securite_de_l_acces_web">Sécurité de l\'accès web (en français)</a> ou <a href="https://www.dokuwiki.org/security#web_access_security">Web Access Security in DokuWiki (en anglais)</a>.';
+$lang['search_exact_match']    = 'Correspondance exacte';
+$lang['search_starts_with']    = 'Commence par';
+$lang['search_ends_with']      = 'Se termine par';
+$lang['search_contains']       = 'Contient';
+$lang['search_custom_match']   = 'personnalisé';
+$lang['search_any_ns']         = 'toute catégorie';
+$lang['search_any_time']       = 'toute date';
+$lang['search_past_7_days']    = 'la semaine dernière';
+$lang['search_past_month']     = 'le mois dernier';
+$lang['search_past_year']      = 'l\'année dernière';
+$lang['search_sort_by_hits']   = 'Trier par nombre de résultats';
+$lang['search_sort_by_mtime']  = 'Trier par date de modification';
+$lang['regmissing']            = 'Désolé, vous devez remplir tous les champs.';
+$lang['reguexists']            = 'Désolé, ce nom d\'utilisateur est déjà pris.';
+$lang['regsuccess']            = 'L\'utilisateur a été créé. Le mot de passe a été expédié par courriel.';
+$lang['regsuccess2']           = 'L\'utilisateur a été créé.';
+$lang['regfail']               = 'L\'utilisateur n\'a pu être crée.';
+$lang['regmailfail']           = 'On dirait qu\'il y a eu une erreur lors de l\'envoi du mot de passe de messagerie. Veuillez contacter l\'administrateur !';
+$lang['regbadmail']            = 'L\'adresse de courriel semble incorrecte. Si vous pensez que c\'est une erreur, contactez l\'administrateur.';
+$lang['regbadpass']            = 'Les deux mots de passe fournis sont différents, veuillez recommencez.';
+$lang['regpwmail']             = 'Votre mot de passe DokuWiki';
+$lang['reghere']               = 'Vous n\'avez pas encore de compte ? Inscrivez-vous';
+$lang['profna']                = 'Ce wiki ne permet pas de modifier les profils';
+$lang['profnochange']          = 'Pas de modification, rien à faire.';
+$lang['profnoempty']           = 'Un nom ou une adresse de courriel vide n\'est pas permis.';
+$lang['profchanged']           = 'Mise à jour du profil réussie.';
+$lang['profnodelete']          = 'Ce wiki ne permet pas la suppression des utilisateurs';
+$lang['profdeleteuser']        = 'Supprimer le compte';
+$lang['profdeleted']           = 'Votre compte utilisateur a été supprimé de ce wiki';
+$lang['profconfdelete']        = 'Je veux supprimer mon compte sur ce wiki. </br> Cette action est irréversible.';
+$lang['profconfdeletemissing'] = 'La case de confirmation n\'est pas cochée';
+$lang['proffail']              = 'Le profil utilisateur n\'a pas été mis à jour.';
+$lang['pwdforget']             = 'Mot de passe oublié ? Obtenez-en un nouveau';
+$lang['resendna']              = 'Ce wiki ne permet pas le renvoi de mot de passe.';
+$lang['resendpwd']             = 'Définir un nouveau mot de passe pour';
+$lang['resendpwdmissing']      = 'Désolé, vous devez remplir tous les champs.';
+$lang['resendpwdnouser']       = 'Désolé, cet utilisateur n\'existe pas dans notre base de données.';
+$lang['resendpwdbadauth']      = 'Désolé, ce code d\'authentification est invalide. Assurez-vous d\'avoir utilisé le lien de confirmation intégral.';
+$lang['resendpwdconfirm']      = 'Un lien de confirmation vient de partir par courriel.';
+$lang['resendpwdsuccess']      = 'Votre nouveau mot de passe vous a été expédié par courriel.';
+$lang['license']               = 'Sauf mention contraire, le contenu de ce wiki est placé sous les termes de la licence suivante :';
+$lang['licenseok']             = 'Note : En modifiant cette page, vous acceptez que le contenu soit placé sous les termes de la licence suivante :';
+$lang['searchmedia']           = 'Chercher le nom de fichier :';
+$lang['searchmedia_in']        = 'Chercher dans %s';
+$lang['txt_upload']            = 'Sélectionnez un fichier à envoyer :';
+$lang['txt_filename']          = 'Envoyer en tant que (optionnel) :';
+$lang['txt_overwrt']           = 'Écraser le fichier cible (s\'il existe)';
+$lang['maxuploadsize']         = 'Taille d\'envoi maximale : %s par fichier';
+$lang['allowedmime']           = 'Liste des extensions de fichier autorisées';
+$lang['lockedby']              = 'Actuellement bloqué par :';
+$lang['lockexpire']            = 'Le blocage expire à :';
 $lang['rssfailed']             = 'Une erreur s\'est produite en récupérant ce flux : ';
 $lang['nothingfound']          = 'Pas de réponse.';
 $lang['mediaselect']           = 'Sélection de fichiers';
 $lang['uploadsucc']            = 'Envoi réussi';
 $lang['uploadfail']            = 'L\'envoi a échoué. Les autorisations sont-elles correctes ?';
 $lang['uploadwrong']           = 'Envoi refusé. Cette extension de fichier est interdite !';
-$lang['uploadexist']           = 'Le fichier existe déjà. L\'envoi a été annulé.';
+$lang['uploadexist']           = 'Le fichier existe déjà. L\'envoi est ignoré.';
 $lang['uploadbadcontent']      = 'Le contenu envoyé ne correspond pas à l\'extension du fichier (%s).';
 $lang['uploadspam']            = 'L\'envoi a été bloqué par la liste noire de l\'anti-spam.';
 $lang['uploadxss']             = 'L\'envoi a été bloqué car son contenu est peut-être malveillant.';
@@ -200,7 +222,7 @@ $lang['mediaview']             = 'Afficher le fichier original';
 $lang['mediaroot']             = 'racine';
 $lang['mediaupload']           = 'Envoyez un fichier dans la catégorie actuelle. Pour créer des sous-catégories, préfixez en le nom du fichier séparées par un double-point, après avoir choisis le(s) fichier(s). Le(s) fichier(s) peuvent également être envoyé(s) par glisser-déposer (drag &amp; drop)';
 $lang['mediaextchange']        = 'Extension du fichier modifiée de .%s en .%s !';
-$lang['reference']             = 'Références pour';
+$lang['reference']             = 'Utilisé sur';
 $lang['ref_inuse']             = 'Le fichier ne peut être effacé car il est toujours utilisé par les pages suivantes :';
 $lang['ref_hidden']            = 'Des références sont présentes dans des pages que vous ne pouvez pas voir (autorisations insuffisantes)';
 $lang['hits']                  = 'Occurrences trouvées';
@@ -220,16 +242,16 @@ $lang['difflastrev']           = 'Dernière révision';
 $lang['diffbothprevrev']       = 'Les deux révisions précédentes';
 $lang['diffbothnextrev']       = 'Les deux révisions suivantes';
 $lang['line']                  = 'Ligne';
-$lang['breadcrumb']            = 'Piste:';
-$lang['youarehere']            = 'Vous êtes ici:';
-$lang['lastmod']               = 'Dernière modification:';
-$lang['by']                    = 'par';
+$lang['breadcrumb']            = 'Piste :';
+$lang['youarehere']            = 'Vous êtes ici :';
+$lang['lastmod']               = 'Dernière modification :';
+$lang['by']                    = 'de';
 $lang['deleted']               = 'supprimée';
 $lang['created']               = 'créée';
 $lang['restored']              = 'ancienne révision (%s) restaurée';
 $lang['external_edit']         = 'modification externe';
 $lang['summary']               = 'Résumé';
-$lang['noflash']               = 'L\'<a href="http://www.adobe.com/products/flashplayer/">extension Adobe Flash</a> est nécessaire pour afficher ce contenu.';
+$lang['noflash']               = 'L\'<a href="http://get.adobe.com/flashplayer">extension Adobe Flash</a> est nécessaire pour afficher ce contenu.';
 $lang['download']              = 'Télécharger cet extrait';
 $lang['tools']                 = 'Outils';
 $lang['user_tools']            = 'Outils pour utilisateurs';
@@ -274,22 +296,22 @@ $lang['upperns']               = 'Aller à la catégorie parente';
 $lang['metaedit']              = 'Modifier les métadonnées';
 $lang['metasaveerr']           = 'Erreur lors de l\'enregistrement des métadonnées';
 $lang['metasaveok']            = 'Métadonnées enregistrées';
-$lang['img_title']             = 'Titre:';
-$lang['img_caption']           = 'Légende:';
-$lang['img_date']              = 'Date:';
-$lang['img_fname']             = 'Nom de fichier:';
-$lang['img_fsize']             = 'Taille:';
-$lang['img_artist']            = 'Photographe:';
-$lang['img_copyr']             = 'Copyright:';
-$lang['img_format']            = 'Format:';
-$lang['img_camera']            = 'Appareil photo:';
-$lang['img_keywords']          = 'Mots-clés:';
-$lang['img_width']             = 'Largeur:';
-$lang['img_height']            = 'Hauteur:';
-$lang['subscr_subscribe_success'] = '%s a été ajouté à la liste des abonnés de %s';
+$lang['img_title']             = 'Titre :';
+$lang['img_caption']           = 'Légende :';
+$lang['img_date']              = 'Date :';
+$lang['img_fname']             = 'Nom de fichier :';
+$lang['img_fsize']             = 'Taille :';
+$lang['img_artist']            = 'Photographe :';
+$lang['img_copyr']             = 'Copyright :';
+$lang['img_format']            = 'Format :';
+$lang['img_camera']            = 'Appareil photo :';
+$lang['img_keywords']          = 'Mots-clés :';
+$lang['img_width']             = 'Largeur :';
+$lang['img_height']            = 'Hauteur :';
+$lang['subscr_subscribe_success'] = '%s a été ajouté à la liste des abonnés à %s';
 $lang['subscr_subscribe_error'] = 'Erreur à l\'ajout de %s à la liste des abonnés de %s';
 $lang['subscr_subscribe_noaddress'] = 'Il n\'y a pas d\'adresse associée à votre identifiant, vous ne pouvez pas être ajouté à la liste des abonnés.';
-$lang['subscr_unsubscribe_success'] = '%s a été supprimé de la liste des abonnés de %s';
+$lang['subscr_unsubscribe_success'] = '%s a été supprimé de la liste des abonnés à %s';
 $lang['subscr_unsubscribe_error'] = 'Erreur au retrait de %s de la liste des abonnés de %s';
 $lang['subscr_already_subscribed'] = '%s est déjà abonné à %s';
 $lang['subscr_not_subscribed'] = '%s n\'est pas abonné à %s';
@@ -309,13 +331,16 @@ $lang['i_wikiname']            = 'Nom du wiki';
 $lang['i_enableacl']           = 'Activer le contrôle d\'accès (recommandé)';
 $lang['i_superuser']           = 'Super-utilisateur';
 $lang['i_problems']            = 'L\'installateur a détecté les problèmes indiqués ci-dessous. Vous ne pouvez pas poursuivre l\'installation tant qu\'ils n\'auront pas été corrigés.';
-$lang['i_modified']            = 'Pour des raisons de sécurité, ce script ne fonctionne qu\'avec une installation neuve et non modifiée de DokuWiki. Vous devriez ré-extraire les fichiers depuis le paquet téléchargé ou consulter les <a href="http://dokuwiki.org/install">instructions d\'installation de DokuWiki</a>';
+$lang['i_modified']            = 'Pour des raisons de sécurité, ce script ne fonctionne qu\'avec une installation neuve et non modifiée de DokuWiki. Vous devriez ré-extraire les fichiers depuis le paquet téléchargé ou consulter les <a href="https://www.dokuwiki.org/install">instructions d\'installation de DokuWiki</a>';
 $lang['i_funcna']              = 'La fonction PHP <code>%s</code> n\'est pas disponible. Peut-être que votre hébergeur web l\'a désactivée ?';
+$lang['i_disabled']            = 'Elle a été désactivée par votre hébergeur';
+$lang['i_funcnmail']           = '<b>Note :</b> La fonction PHP mail n\'est pas disponible. %s Si vous ne pouvez pas l\'activer, vous pourriez installer le <a href="https://www.dokuwiki.org/plugin:smtp">greffon smtp</a>.';
 $lang['i_phpver']              = 'Votre version de PHP (%s) est antérieure à la version requise (%s). Vous devez mettre à jour votre installation de PHP.';
 $lang['i_mbfuncoverload']      = 'Il faut désactiver mbstring.func_overload dans php.ini pour DokuWiki';
-$lang['i_permfail']            = '<code>%s</code> n\'est pas accessible en écriture pour DokuWiki. Vous devez corriger les autorisations de ce répertoire !';
+$lang['i_urandom']             = 'DokuWiki ne peut créer de nombres cryptographiquement sûrs pour les cookies. Vous voudrez peut-être vérifier que le réglage open_basedir dans php.ini permet l\'accès à <code>/dev/urandom</code>.';
+$lang['i_permfail']            = '<code>%s</code> n\'est pas accessible en écriture pour DokuWiki. Vous devez corriger les autorisations de ce dossier !';
 $lang['i_confexists']          = '<code>%s</code> existe déjà';
-$lang['i_writeerr']            = 'Impossible de créer <code>%s</code>. Vous devez vérifier les autorisations des répertoires/fichiers et créer le fichier manuellement.';
+$lang['i_writeerr']            = 'Impossible de créer <code>%s</code>. Vous devez vérifier les autorisations des dossiers/fichiers et créer le fichier manuellement.';
 $lang['i_badhash']             = 'dokuwiki.php non reconnu ou modifié (hash=<code>%s</code>)';
 $lang['i_badval']              = '<code>%s</code> - valeur interdite ou vide';
 $lang['i_success']             = 'L\'installation s\'est terminée avec succès. Vous pouvez maintenant supprimer le fichier « install.php ». Continuer avec <a href="doku.php?id=wiki:welcome">votre nouveau DokuWiki</a>.';
@@ -363,9 +388,12 @@ $lang['media_perm_upload']     = 'Désolé, vous n\'avez pas l\'autorisation d\'
 $lang['media_update']          = 'Envoyer une nouvelle version';
 $lang['media_restore']         = 'Restaurer cette version';
 $lang['media_acl_warning']     = 'En raison des restrictions dans les ACL et de pages cachées, cette liste peut ne pas être complète.';
+$lang['email_fail']            = 'La fonction PHP mail() est absente ou désactivée. Le message suivant n’est pas parti :';
 $lang['currentns']             = 'Catégorie courante';
 $lang['searchresult']          = 'Résultat de la recherche';
 $lang['plainhtml']             = 'HTML brut';
 $lang['wikimarkup']            = 'Wiki balise';
 $lang['page_nonexist_rev']     = 'La page n\'existait pas le %s. Elle a été créée le <a href="%s">%s</a>.';
-$lang['unable_to_parse_date']  = 'Ne peut analyser le paramètre date "%s".';
+$lang['unable_to_parse_date']  = 'Impossible d\'analyser le paramètre temporel at "%s".';
+$lang['email_signature_text']  = 'Courriel envoyé par DokuWiki depuis
+@DOKUWIKIURL@';
