@@ -109,6 +109,7 @@ $lang['js']['media_done_btn']  = 'Xong';
 $lang['js']['media_drop']      = 'Kéo tập tin vào đây để tải lên';
 $lang['js']['media_cancel']    = 'xóa';
 $lang['js']['media_overwrt']   = 'Ghi đè các tập tin hiện có';
+$lang['js']['data_insecure']   = 'CẢNH BÁO: Có vẻ như đường dẫn dữ liệu của bạn không được bảo mật đúng cách. Xin vui lòng đọc <a href="https://www.dokuwiki.org/security#web_access_security">Web Access Security in DokuWiki</a>.';
 $lang['search_exact_match']    = 'Khớp chính xác';
 $lang['search_starts_with']    = 'Bắt đầu với';
 $lang['search_ends_with']      = 'Kết thúc bằng';
@@ -130,7 +131,7 @@ $lang['regmailfail']           = 'Có vẻ như đã xảy ra lỗi khi gửi th
 $lang['regbadmail']            = 'Địa chỉ thư điện tử được cung cấp có vẻ không hợp lệ - nếu bạn nghĩ đây là lỗi, hãy liên hệ với quản trị viên';
 $lang['regbadpass']            = 'Hai mật khẩu đã nhập không giống nhau, vui lòng thử lại.';
 $lang['regpwmail']             = 'Mật khẩu DokuWiki của bạn';
-$lang['reghere']               = 'Bạn chưa có tài khoản? Hãy lấy một cái';
+$lang['reghere']               = 'Bạn chưa có tài khoản? Hãy tạo một cái';
 $lang['profna']                = 'Wiki này không hỗ trợ sửa đổi hồ sơ';
 $lang['profnochange']          = 'Không có thay đổi, không có gì để làm.';
 $lang['profnoempty']           = 'Không được bỏ trống tên hoặc địa chỉ thư điện tử.';
@@ -141,7 +142,7 @@ $lang['profdeleted']           = 'Tài khoản thành viên của bạn đã b
 $lang['profconfdelete']        = 'Tôi muốn xóa tài khoản của tôi khỏi wiki này. <br/> Hành động này không thể hoàn tác.';
 $lang['profconfdeletemissing'] = 'Hộp kiểm xác nhận chưa được đánh dấu';
 $lang['proffail']              = 'Hồ sơ thành viên chưa được cập nhật.';
-$lang['pwdforget']             = 'Bạn quên mật khẩu? Thử một cái mới';
+$lang['pwdforget']             = 'Bạn quên mật khẩu? Tạo một cái mới';
 $lang['resendna']              = 'Wiki này không hỗ trợ gửi lại mật khẩu.';
 $lang['resendpwd']             = 'Đặt mật khẩu mới cho';
 $lang['resendpwdmissing']      = 'Xin lỗi, bạn phải điền vào tất cả các trường.';
@@ -157,6 +158,7 @@ $lang['txt_upload']            = 'Chọn tập tin để tải lên:';
 $lang['txt_filename']          = 'Tải lên dưới dạng (tùy chọn):';
 $lang['txt_overwrt']           = 'Ghi đè tập tin hiện có';
 $lang['maxuploadsize']         = 'Tải lên tối đa. %s mỗi tập tin.';
+$lang['allowedmime']           = 'Danh sách các phần mở rộng tập tin được phép';
 $lang['lockedby']              = 'Hiện đang bị khóa bởi:';
 $lang['lockexpire']            = 'Khóa hết hạn vào lúc:';
 $lang['rssfailed']             = 'Đã xảy ra lỗi khi tìm nạp nguồn cấp dữ liệu này:';
@@ -205,12 +207,12 @@ $lang['breadcrumb']            = 'Trang đã xem:';
 $lang['youarehere']            = 'Bạn đang ở đây:';
 $lang['lastmod']               = 'Sửa đổi lần cuối:';
 $lang['by']                    = 'bởi';
-$lang['deleted']               = 'bị xoá';
+$lang['deleted']               = 'đã bị xoá';
 $lang['created']               = 'đã tạo';
 $lang['restored']              = 'đã khôi phục phiên bản cũ (%s)';
 $lang['external_edit']         = 'sửa đổi bên ngoài';
 $lang['summary']               = 'Tóm lược sửa đổi';
-$lang['noflash']               = 'Cần có <a href="http://www.adobe.com/products/flashplayer/">Adobe Flash Plugin</a> mới có thể xem được nội dung này.';
+$lang['noflash']               = 'Cần có <a href="http://get.adobe.com/flashplayer">Adobe Flash Plugin</a> mới có thể xem được nội dung này.';
 $lang['download']              = 'Tải xuống đoạn trích';
 $lang['tools']                 = 'Công cụ';
 $lang['user_tools']            = 'Công cụ thành viên';
@@ -292,10 +294,10 @@ $lang['i_superuser']           = 'Siêu thành viên';
 $lang['i_problems']            = 'Trình cài đặt tìm thấy một số vấn đề, được chỉ ra bên dưới. Bạn không thể tiếp tục cho đến khi bạn đã sửa chúng.';
 $lang['i_modified']            = 'Vì lý do bảo mật, tập lệnh này sẽ chỉ hoạt động với bản cài đặt Dokuwiki mới và chưa được sửa đổi.
                                   Bạn nên trích xuất lại các tập tin từ gói đã tải xuống hoặc tham khảo
-                    <a href="http://dokuwiki.org/install">Hướng dẫn cài đặt Dokuwiki</a> đầy đủ';
+                    <a href="https://www.dokuwiki.org/install">Hướng dẫn cài đặt Dokuwiki</a> đầy đủ';
 $lang['i_funcna']              = 'Hàm PHP <code>%s</code> không có sẵn. Có lẽ nhà cung cấp dịch vụ lưu trữ của bạn đã vô hiệu hóa nó vì một số lý do?';
 $lang['i_disabled']            = 'Nó đã bị vô hiệu hóa bởi nhà cung cấp của bạn.';
-$lang['i_funcnmail']           = '<b>Lưu ý:</b> Không có sẵn hàm PHP mail. %s Nếu nó vẫn không có sẵn, bạn có thể cài đặt <a href="http://dokuwiki.org/plugins/smtp">smtp plugin</a>.';
+$lang['i_funcnmail']           = '<b>Lưu ý:</b> Không có sẵn hàm PHP mail. %s Nếu nó vẫn không có sẵn, bạn có thể cài đặt <a href="https://www.dokuwiki.org/plugin:smtp">smtp plugin</a>.';
 $lang['i_phpver']              = 'Phiên bản PHP <code>%s</code> hiện taị thấp hơn mức <code>%s</code> cần thiết. Bạn cần nâng cấp cài đặt PHP của bạn.';
 $lang['i_mbfuncoverload']      = 'mbopes.func_overload phải bị vô hiệu trong php.ini để chạy DokuWiki.';
 $lang['i_urandom']             = 'DokuWiki không thể tạo số mật mã an toàn cho cookie. Bạn có thể muốn kiểm tra cài đặt open_basingir trong php.ini để truy cập <code>/dev/urandom</code> thích hợp.';
