@@ -1,20 +1,43 @@
 <?php
+
 /**
- * Chinese(Simplified) language file
- *
  * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
+ *
+ * @author VinnieChow <zsz33@qq.com>
+ * @author Lakejason0 <lakesarchive@outlook.com>
+ * @author Phy <dokuwiki@phy25.com>
+ * @author Jenxi <seow@jenxi.com>
+ * @author FENG.JIE <ahx@qq.com>
+ * @author Xin <chenxin1034@gmail.com>
+ * @author HaoNan <haonan@zhuoming.info>
+ * @author Aaron Zhou <iradio@163.com>
+ * @author lempel <riverlempel@hotmail.com>
  * @author ZDYX <zhangduyixiong@gmail.com>
  * @author http://www.chinese-tools.com/tools/converter-tradsimp.html
  * @author George Sheraton <guxd@163.com>
  * @author Simon zhan <simonzhan@21cn.com>
- * @author mr.jinyi@gmail.com
  * @author ben <ben@livetom.com>
  * @author lainme <lainme993@gmail.com>
  * @author caii <zhoucaiqi@gmail.com>
  * @author Hiphen Lee <jacob.b.leung@gmail.com>
- * @author caii, patent agent in China <zhoucaiqi@gmail.com>
- * @author lainme993@gmail.com
  * @author Shuo-Ting Jian <shoting@gmail.com>
+ * @author Rachel <rzhang0802@gmail.com>
+ * @author Donald <donaldtcong@gmail.com>
+ * @author Yangyu Huang <yangyu.huang@gmail.com>
+ * @author anjianshi <anjianshi@gmail.com>
+ * @author oott123 <ip.192.168.1.1@qq.com>
+ * @author Cupen <Cupenoruler@foxmail.com>
+ * @author xiqingongzi <Xiqingongzi@Gmail.com>
+ * @author qinghao <qingxianhao@gmail.com>
+ * @author Yuwei Sun <yuwei@hrz.tu-chemnitz.de>
+ * @author Errol <errol@hotmail.com>
+ * @author Garfield <garfield_550@outlook.com>
+ * @author JellyChen <451453325@qq.com>
+ * @author tai <tai_tang@126.com>
+ * @author 高博 <bobnemo1983@gmail.com>
+ * @author hznupeter <qiujiongtao@163.com>
+ * @author kuma <kuma000@qq.com>
+ * @author phy25 <git@phy25.com>
  */
 $lang['encoding']              = 'utf-8';
 $lang['direction']             = 'ltr';
@@ -30,7 +53,7 @@ $lang['btn_create']            = '创建该页面';
 $lang['btn_search']            = '搜索';
 $lang['btn_save']              = '保存';
 $lang['btn_preview']           = '预览';
-$lang['btn_top']               = '到顶部';
+$lang['btn_top']               = '回到顶部';
 $lang['btn_newer']             = '<< 较新的';
 $lang['btn_older']             = '较旧的 >>';
 $lang['btn_revs']              = '修订记录';
@@ -46,7 +69,6 @@ $lang['btn_update']            = '更新';
 $lang['btn_delete']            = '删除';
 $lang['btn_back']              = '返回';
 $lang['btn_backlink']          = '反向链接';
-$lang['btn_backtomedia']       = '返回到媒体文件选择工具';
 $lang['btn_subscribe']         = '订阅本页更改';
 $lang['btn_profile']           = '更新个人信息';
 $lang['btn_reset']             = '重设';
@@ -58,7 +80,10 @@ $lang['btn_revert']            = '恢复';
 $lang['btn_register']          = '注册';
 $lang['btn_apply']             = '应用';
 $lang['btn_media']             = '媒体管理器';
-$lang['loggedinas']            = '登录为';
+$lang['btn_deleteuser']        = '移除我的账户';
+$lang['btn_img_backto']        = '返回到 %s';
+$lang['btn_mediaManager']      = '在媒体管理器中查看';
+$lang['loggedinas']            = '登录为:';
 $lang['user']                  = '用户名';
 $lang['pass']                  = '密码';
 $lang['newpass']               = '请输入新密码';
@@ -69,40 +94,13 @@ $lang['fullname']              = '全名';
 $lang['email']                 = 'E-Mail';
 $lang['profile']               = '用户信息';
 $lang['badlogin']              = '对不起，用户名或密码错误。';
+$lang['badpassconfirm']        = '对不起，密码错误';
 $lang['minoredit']             = '细微修改';
 $lang['draftdate']             = '草稿自动保存于';
 $lang['nosecedit']             = '在您编辑期间本页刚被他人修改过，局部信息已过期，故载入全页。';
-$lang['regmissing']            = '对不起，您必须填写所有的区域。';
-$lang['reguexists']            = '对不起，该用户名已经存在。';
-$lang['regsuccess']            = '新用户已建立，密码将通过电子邮件发送给您。';
-$lang['regsuccess2']           = '新用户已建立';
-$lang['regmailfail']           = '发送密码邮件时产生错误。请联系管理员！';
-$lang['regbadmail']            = '您输入的邮件地址有问题——如果您认为这是系统错误，请联系管理员。';
-$lang['regbadpass']            = '您输入的密码与系统产生的不符，请重试。';
-$lang['regpwmail']             = '您的 DokuWiki 密码';
-$lang['reghere']               = '还没有账号？立即注册';
-$lang['profna']                = '本维基不支持修改个人信息';
-$lang['profnochange']          = '没有改动，不进行操作。';
-$lang['profnoempty']           = '不允许使用空的用户名或邮件地址。';
-$lang['profchanged']           = '用户信息更新成功。';
-$lang['pwdforget']             = '忘记密码？立即获取新密码';
-$lang['resendna']              = '本维基不支持二次发送密码。';
-$lang['resendpwd']             = '设置新密码用于';
-$lang['resendpwdmissing']      = '对不起，您必须填写所有的区域。';
-$lang['resendpwdnouser']       = '对不起，在我们的用户数据中找不到该用户。';
-$lang['resendpwdbadauth']      = '对不起，该认证码错误。请使用完整的确认链接。';
-$lang['resendpwdconfirm']      = '确认链接已经通过邮件发送给您了。';
-$lang['resendpwdsuccess']      = '您的新密码已经通过邮件发送给您了。';
-$lang['license']               = '除额外注明的地方外，本维基上的内容按下列许可协议发布：';
-$lang['licenseok']             = '当您选择开始编辑本页，即寓示你同意将你贡献的内容按下列许可协议发布：';
-$lang['searchmedia']           = '查找文件名：';
-$lang['searchmedia_in']        = '在%s中查找';
-$lang['txt_upload']            = '选择要上传的文件';
-$lang['txt_filename']          = '上传并重命名为（可选）';
-$lang['txt_overwrt']           = '覆盖已存在的同名文件';
-$lang['maxuploadsize']         = '上传限制。每个文件 %s';
-$lang['lockedby']              = '目前已被下列人员锁定';
-$lang['lockexpire']            = '预计锁定解除于';
+$lang['searchcreatepage']      = '如果没有找到搜索内容，你可以创建或编辑以你查找内容命名的页面 %s。';
+$lang['search_fullresults']    = '全文搜索结果';
+$lang['js']['search_toggle_tools'] = '触发搜索工具';
 $lang['js']['willexpire']      = '您对本页的独有编辑权将于一分钟之后解除。\n为了防止与其他人的编辑冲突，请使用预览按钮重设计时器。';
 $lang['js']['notsavedyet']     = '未保存的更改将丢失。
 真的要继续？';
@@ -146,10 +144,61 @@ $lang['js']['media_done_btn']  = '完成';
 $lang['js']['media_drop']      = '拖拽文件到此处来上传';
 $lang['js']['media_cancel']    = '删除';
 $lang['js']['media_overwrt']   = '覆盖已存在的文件';
+$lang['js']['data_insecure']   = '警告： 看起来你的数据集不太安全。 请参考以下链接<a href="https://www.dokuwiki.org/security#web_access_security">Web Access Security in DokuWiki</a>。';
+$lang['search_exact_match']    = '精确匹配';
+$lang['search_starts_with']    = '开始于';
+$lang['search_ends_with']      = '结束于';
+$lang['search_contains']       = '包含';
+$lang['search_custom_match']   = '定制';
+$lang['search_any_ns']         = '任何名空间';
+$lang['search_any_time']       = '任意时间';
+$lang['search_past_7_days']    = '上周';
+$lang['search_past_month']     = '上月';
+$lang['search_past_year']      = '去年';
+$lang['search_sort_by_hits']   = '按照点击率排序';
+$lang['search_sort_by_mtime']  = '按照最新更新时间排序';
+$lang['regmissing']            = '对不起，您必须填写所有的字段。';
+$lang['reguexists']            = '对不起，该用户名已经存在。';
+$lang['regsuccess']            = '新用户已建立，密码将通过电子邮件发送给您。';
+$lang['regsuccess2']           = '新用户已建立';
+$lang['regfail']               = '用户不能被创建。';
+$lang['regmailfail']           = '发送密码邮件时产生错误。请联系管理员！';
+$lang['regbadmail']            = '您输入的邮件地址有问题——如果您认为这是系统错误，请联系管理员。';
+$lang['regbadpass']            = '您输入的密码与系统产生的不符，请重试。';
+$lang['regpwmail']             = '您的 DokuWiki 密码';
+$lang['reghere']               = '还没有账号？立即注册';
+$lang['profna']                = '本维基不允许修改个人信息';
+$lang['profnochange']          = '没有改动，不进行操作。';
+$lang['profnoempty']           = '不允许使用空的用户名或邮件地址。';
+$lang['profchanged']           = '用户信息更新成功。';
+$lang['profnodelete']          = '这个 wiki 不支持删除用户';
+$lang['profdeleteuser']        = '删除账号';
+$lang['profdeleted']           = '你的用户已经从这个 wiki 中删除';
+$lang['profconfdelete']        = '我希望删除我的账户。<br/>这项操作无法撤销。';
+$lang['profconfdeletemissing'] = '确认框未勾选';
+$lang['proffail']              = '用户设置没有更新。';
+$lang['pwdforget']             = '忘记密码？立即获取新密码';
+$lang['resendna']              = '本维基不支持二次发送密码。';
+$lang['resendpwd']             = '设置新密码用于';
+$lang['resendpwdmissing']      = '对不起，您必须填写所有的区域。';
+$lang['resendpwdnouser']       = '对不起，在我们的用户数据中找不到该用户。';
+$lang['resendpwdbadauth']      = '对不起，该认证码错误。请使用完整的确认链接。';
+$lang['resendpwdconfirm']      = '确认链接已经通过邮件发送给您了。';
+$lang['resendpwdsuccess']      = '您的新密码已经通过邮件发送给您了。';
+$lang['license']               = '除额外注明的地方外，本维基上的内容按下列许可协议发布：';
+$lang['licenseok']             = '当您选择开始编辑本页，即寓示你同意将你贡献的内容按下列许可协议发布：';
+$lang['searchmedia']           = '查找文件名：';
+$lang['searchmedia_in']        = '在%s中查找';
+$lang['txt_upload']            = '选择要上传的文件:';
+$lang['txt_filename']          = '上传并重命名为（可选）:';
+$lang['txt_overwrt']           = '覆盖已存在的同名文件';
+$lang['maxuploadsize']         = '上传限制。每个文件 %s';
+$lang['allowedmime']           = '允许文件扩展名列表';
+$lang['lockedby']              = '目前已被下列人员锁定:';
+$lang['lockexpire']            = '预计锁定解除于:';
 $lang['rssfailed']             = '获取该 RSS 信息时产生错误：';
 $lang['nothingfound']          = '什么都没有找到。';
 $lang['mediaselect']           = '媒体文件';
-$lang['fileupload']            = '上传媒体文件';
 $lang['uploadsucc']            = '上传成功';
 $lang['uploadfail']            = '上传失败。也许是上传权限错误。';
 $lang['uploadwrong']           = '上传失败。该扩展名被禁止。';
@@ -183,17 +232,22 @@ $lang['difflink']              = '到此差别页面的链接';
 $lang['diff_type']             = '查看差异：';
 $lang['diff_inline']           = '行内显示';
 $lang['diff_side']             = '并排显示';
+$lang['diffprevrev']           = '前一修订版';
+$lang['diffnextrev']           = '后一修订版';
+$lang['difflastrev']           = '上一修订版';
+$lang['diffbothprevrev']       = '两侧同时换到之前的修订记录';
+$lang['diffbothnextrev']       = '两侧同时换到之后的修订记录';
 $lang['line']                  = '行';
-$lang['breadcrumb']            = '您的足迹';
-$lang['youarehere']            = '您在这里';
-$lang['lastmod']               = '最后更改';
+$lang['breadcrumb']            = '您的足迹:';
+$lang['youarehere']            = '您在这里:';
+$lang['lastmod']               = '最后更改:';
 $lang['by']                    = '由';
 $lang['deleted']               = '移除';
 $lang['created']               = '创建';
 $lang['restored']              = '已恢复为旧版 (%s)';
 $lang['external_edit']         = '外部编辑';
 $lang['summary']               = '编辑摘要';
-$lang['noflash']               = '需要 <a href="http://www.adobe.com/products/flashplayer/">Adobe Flash 插件</a> 来播放本内容。 ';
+$lang['noflash']               = '需要 <a href="https://get.adobe.com/flashplayer">Adobe Flash 插件</a> 来播放本内容。 ';
 $lang['download']              = '下载片段';
 $lang['tools']                 = '工具';
 $lang['user_tools']            = '用户工具';
@@ -235,24 +289,21 @@ $lang['qb_sig']                = '插入签名';
 $lang['qb_smileys']            = '表情符号';
 $lang['qb_chars']              = '特殊字符';
 $lang['upperns']               = '跳转到父级名空间';
-$lang['admin_register']        = '添加新用户';
 $lang['metaedit']              = '编辑元数据';
 $lang['metasaveerr']           = '写入元数据失败';
 $lang['metasaveok']            = '元数据已保存';
-$lang['img_backto']            = '返回到';
-$lang['img_title']             = '标题';
-$lang['img_caption']           = '说明';
-$lang['img_date']              = '日期';
-$lang['img_fname']             = '名称';
-$lang['img_fsize']             = '大小';
-$lang['img_artist']            = '摄影师';
-$lang['img_copyr']             = '版权';
-$lang['img_format']            = '格式';
-$lang['img_camera']            = '相机';
-$lang['img_keywords']          = '关键字';
-$lang['img_width']             = '宽度';
-$lang['img_height']            = '高度';
-$lang['img_manager']           = '在媒体管理器中查看';
+$lang['img_title']             = '标题:';
+$lang['img_caption']           = '说明:';
+$lang['img_date']              = '日期:';
+$lang['img_fname']             = '名称:';
+$lang['img_fsize']             = '大小:';
+$lang['img_artist']            = '摄影师:';
+$lang['img_copyr']             = '版权:';
+$lang['img_format']            = '格式:';
+$lang['img_camera']            = '相机:';
+$lang['img_keywords']          = '关键字:';
+$lang['img_width']             = '宽度:';
+$lang['img_height']            = '高度:';
 $lang['subscr_subscribe_success'] = '添加 %s 到 %s 的订阅列表';
 $lang['subscr_subscribe_error'] = '添加 %s 到 %s 的订阅列表中出现错误';
 $lang['subscr_subscribe_noaddress'] = '没有与您登录信息相关联的地址，您无法被添加到订阅列表';
@@ -269,35 +320,41 @@ $lang['subscr_m_receive']      = '接收';
 $lang['subscr_style_every']    = '对每次更改发送邮件';
 $lang['subscr_style_digest']   = '对每个页面发送更改的摘要邮件（每 %.2f 天）';
 $lang['subscr_style_list']     = '自上封邮件以来更改的页面的列表（每 %.2f 天）';
-$lang['authmodfailed']         = '错误的用户认证设置。请通知维基管理员。';
 $lang['authtempfail']          = '用户认证暂时无法使用。如果该状态一直存在，请通知维基管理员。';
-$lang['authpwdexpire']         = '您的密码将在 %d 天内过期，请尽快更改';
 $lang['i_chooselang']          = '选择您的语言';
 $lang['i_installer']           = 'DokuWiki 安装工具';
 $lang['i_wikiname']            = '维基名称';
 $lang['i_enableacl']           = '启用 ACL（推荐）';
 $lang['i_superuser']           = '超级用户';
 $lang['i_problems']            = '安装工具发现一些问题，已在下面列出。您必须先修复这些问题，才能继续安装。';
-$lang['i_modified']            = '由于安全上的考虑，该脚本只能用于全新且做任何改动的 Dokuwiki 安装包。
+$lang['i_modified']            = '由于安全上的考虑，该脚本只能用于全新且做任何改动的 DokuWiki 安装包。
                          您可以重新解压下载的程序包，或查阅完整的
-                         <a href="http://dokuwiki.org/install">Dokuwiki 安装指南</a>';
+                         <a href="https://www.dokuwiki.org/install">Dokuwiki 安装指南</a>';
 $lang['i_funcna']              = 'PHP 功能 <code>%s</code> 无法使用。也许您的服务器提供商因为某些原因禁用了它。';
+$lang['i_disabled']            = '它已经被您的服务商禁用';
+$lang['i_funcnmail']           = '<b>注意：</b> PHP邮件功能不可用。%s 如果仍然不可用，则可以安装<a href="https://www.dokuwiki.org/plugin:smtp">SMTP 插件</a>。';
 $lang['i_phpver']              = '您的 PHP 版本 <code>%s</code> 低于最低要求的 <code>%s</code>。您需要升级您的 PHP 版本。';
+$lang['i_mbfuncoverload']      = '为了运行DokuWiki，您必须在php.ini中禁用mbstring.func_overload。';
+$lang['i_urandom']             = 'DokuWiki 无法为 Cookie 创建密码安全的数字。您可能需要检查 php.ini 中的 open_basedir 设置，以获取正确的<code>/dev/urandom</code>访问权限。';
 $lang['i_permfail']            = 'DokuWiki 无法写入 <code>%s</code>。您需要修改该路径的权限设定！';
 $lang['i_confexists']          = '<code>%s</code> 已经存在';
 $lang['i_writeerr']            = '无法创建 <code>%s</code>。您需要检查该路径/文件的权限设定并手动创建该文件。';
-$lang['i_badhash']             = '无法识别的或被修改的 dokuwiki.php（值=<code>%s</code>）';
+$lang['i_badhash']             = '无法识别的或被修改的 dokuwiki.php（哈希值=<code>%s</code>）';
 $lang['i_badval']              = '<code>%s</code> - 非法或空值';
 $lang['i_success']             = '配置成功完成。您现在可以删除 install.php 了。继续进入
-                        <a href="doku.php">您全新的 DokuWiki</a>。';
-$lang['i_failure']             = '写入配置文件的时候产生一些错误。在使用 <a href="doku.php">您全新安装的 DokuWiki</a> 前
+                        <a href="doku.php?id=wiki:welcome">您全新的 DokuWiki</a>。';
+$lang['i_failure']             = '写入配置文件的时候产生一些错误。在使用 <a href="doku.php?id=wiki:welcome">您全新安装的 DokuWiki</a> 前
                          您需要手动修复它们。';
 $lang['i_policy']              = '初始的 ACL 政策';
 $lang['i_pol0']                = '开放的维基（任何人都有读、写、上传的权限）';
 $lang['i_pol1']                = '公共的维基（任何人都有读的权限，只有注册用户才有写和上传的权限）';
 $lang['i_pol2']                = '关闭的维基（只有注册用户才有读、写、上传的权限）';
+$lang['i_allowreg']            = '允许用户自行注册';
 $lang['i_retry']               = '重试';
 $lang['i_license']             = '请选择您希望的内容发布许可协议：';
+$lang['i_license_none']        = '不要显示任何许可协议信息';
+$lang['i_pop_field']           = '请帮助我们改进 DokuWiki 的体验：';
+$lang['i_pop_label']           = '每个月向 DokuWiki 开发者发送匿名的使用数据';
 $lang['recent_global']         = '您当前看到的是<b>%s</b> 名称空间的变动。你还可以在<a href="%s">查看整个维基的近期变动</a>。';
 $lang['years']                 = '%d年前';
 $lang['months']                = '%d月前';
@@ -330,3 +387,13 @@ $lang['media_perm_read']       = '抱歉，您没有足够权限读取这些文
 $lang['media_perm_upload']     = '抱歉，您没有足够权限来上传文件。';
 $lang['media_update']          = '上传新版本';
 $lang['media_restore']         = '恢复这个版本';
+$lang['media_acl_warning']     = '此列表可能不完全是由ACL限制和隐藏的页面。';
+$lang['email_fail']            = 'PHP mail() 不存在或被禁用。未发送以下电子邮件：';
+$lang['currentns']             = '当前命名空间';
+$lang['searchresult']          = '搜索结果';
+$lang['plainhtml']             = '纯HTML';
+$lang['wikimarkup']            = 'Wiki Markup 语言';
+$lang['page_nonexist_rev']     = '页面在 %s 不存在。它曾创建于 <a href="%s">%s</a>。';
+$lang['unable_to_parse_date']  = '无法解析参数 "%s"。';
+$lang['email_signature_text']  = '本邮件由 DokuWiki 自动创建
+@DOKUWIKIURL@';
