@@ -6,7 +6,9 @@
  * @author     Andreas Gohr <andi@splitbrain.org>
  */
 
-if(!defined('DOKU_INC')) die('meh.');
+use dokuwiki\Extension\AdminPlugin;
+use dokuwiki\Extension\Event;
+use dokuwiki\File\PageResolver;
 
 /**
  * Access a template file
@@ -80,9 +82,9 @@ function tpl_content($prependTOC = true) {
     $INFO['prependTOC'] = $prependTOC;
 
     ob_start();
-    trigger_event('TPL_ACT_RENDER', $ACT, 'tpl_content_core');
+    Event::createAndTrigger('TPL_ACT_RENDER', $ACT, 'tpl_content_core');
     $html_output = ob_get_clean();
-    trigger_event('TPL_CONTENT_DISPLAY', $html_output, 'ptln');
+    Event::createAndTrigger('TPL_CONTENT_DISPLAY', $html_output, 'ptln');
 
     return !empty($html_output);
 }
@@ -93,90 +95,13 @@ function tpl_content($prependTOC = true) {
  * @return bool
  */
 function tpl_content_core() {
-    global $ACT;
-    global $TEXT;
-    global $PRE;
-    global $SUF;
-    global $SUM;
-    global $IDX;
-    global $INPUT;
-
-    switch($ACT) {
-        case 'show':
-            html_show();
-            break;
-        /** @noinspection PhpMissingBreakStatementInspection */
-        case 'locked':
-            html_locked();
-        case 'edit':
-        case 'recover':
-            html_edit();
-            break;
-        case 'preview':
-            html_edit();
-            html_show($TEXT);
-            break;
-        case 'draft':
-            html_draft();
-            break;
-        case 'search':
-            html_search();
-            break;
-        case 'revisions':
-            html_revisions($INPUT->int('first'));
-            break;
-        case 'diff':
-            html_diff();
-            break;
-        case 'recent':
-            $show_changes = $INPUT->str('show_changes');
-            if (empty($show_changes)) {
-                $show_changes = get_doku_pref('show_changes', $show_changes);
-            }
-            html_recent($INPUT->extract('first')->int('first'), $show_changes);
-            break;
-        case 'index':
-            html_index($IDX); #FIXME can this be pulled from globals? is it sanitized correctly?
-            break;
-        case 'backlink':
-            html_backlinks();
-            break;
-        case 'conflict':
-            html_conflict(con($PRE, $TEXT, $SUF), $SUM);
-            html_diff(con($PRE, $TEXT, $SUF), false);
-            break;
-        case 'login':
-            html_login();
-            break;
-        case 'register':
-            html_register();
-            break;
-        case 'resendpwd':
-            html_resendpwd();
-            break;
-        case 'denied':
-            html_denied();
-            break;
-        case 'profile' :
-            html_updateprofile();
-            break;
-        case 'admin':
-            tpl_admin();
-            break;
-        case 'subscribe':
-            tpl_subscribe();
-            break;
-        case 'media':
-            tpl_media();
-            break;
-        default:
-            $evt = new Doku_Event('TPL_ACT_UNKNOWN', $ACT);
-            if($evt->advise_before()) {
-                msg("Failed to handle command: ".hsc($ACT), -1);
-            }
-            $evt->advise_after();
-            unset($evt);
-            return false;
+    $router = \dokuwiki\ActionRouter::getInstance();
+    try {
+        $router->getAction()->tplContent();
+    } catch(\dokuwiki\Action\Exception\FatalException $e) {
+        // there was no content for the action
+        msg(hsc($e->getMessage()), -1);
+        return false;
     }
     return true;
 }
@@ -219,14 +144,14 @@ function tpl_toc($return = false) {
         }
     } elseif($ACT == 'admin') {
         // try to load admin plugin TOC
-        /** @var $plugin DokuWiki_Admin_Plugin */
+        /** @var $plugin AdminPlugin */
         if ($plugin = plugin_getRequestAdminPlugin()) {
             $toc = $plugin->getTOC();
             $TOC = $toc; // avoid later rebuild
         }
     }
 
-    trigger_event('TPL_TOC_RENDER', $toc, null, false);
+    Event::createAndTrigger('TPL_TOC_RENDER', $toc, null, false);
     $html = html_TOC($toc);
     if($return) return $html;
     echo $html;
@@ -252,7 +177,7 @@ function tpl_admin() {
 
         if(in_array($class, $pluginlist)) {
             // attempt to load the plugin
-            /** @var $plugin DokuWiki_Admin_Plugin */
+            /** @var $plugin AdminPlugin */
             $plugin = plugin_load('admin', $class);
         }
     }
@@ -262,7 +187,8 @@ function tpl_admin() {
         if($INFO['prependTOC']) tpl_toc();
         $plugin->html();
     } else {
-        html_admin();
+        $admin = new dokuwiki\Ui\Admin();
+        $admin->show();
     }
     return true;
 }
@@ -318,6 +244,17 @@ function tpl_metaheaders($alt = true) {
         );
     }
 
+    if (actionOK('manifest')) {
+        $head['link'][] = array('rel'=> 'manifest', 'href'=> DOKU_BASE.'lib/exe/manifest.php');
+    }
+
+    $styleUtil = new \dokuwiki\StyleUtils();
+    $styleIni = $styleUtil->cssStyleini();
+    $replacements = $styleIni['replacements'];
+    if (!empty($replacements['__theme_color__'])) {
+        $head['meta'][] = array('name' => 'theme-color', 'content' => $replacements['__theme_color__']);
+    }
+
     if($alt) {
         if(actionOK('rss')) {
             $head['link'][] = array(
@@ -327,7 +264,7 @@ function tpl_metaheaders($alt = true) {
             $head['link'][] = array(
                 'rel'  => 'alternate', 'type'=> 'application/rss+xml',
                 'title'=> $lang['currentns'],
-                'href' => DOKU_BASE.'feed.php?mode=list&ns='.$INFO['namespace']
+                'href' => DOKU_BASE.'feed.php?mode=list&ns='.(isset($INFO) ? $INFO['namespace'] : '')
             );
         }
         if(($ACT == 'show' || $ACT == 'search') && $INFO['writable']) {
@@ -361,11 +298,11 @@ function tpl_metaheaders($alt = true) {
         }
     }
 
-    // setup robot tags apropriate for different modes
+    // setup robot tags appropriate for different modes
     if(($ACT == 'show' || $ACT == 'export_xhtml') && !$REV) {
         if($INFO['exists']) {
             //delay indexing:
-            if((time() - $INFO['lastmod']) >= $conf['indexdelay']) {
+            if((time() - $INFO['lastmod']) >= $conf['indexdelay'] && !isHiddenPage($ID) ) {
                 $head['meta'][] = array('name'=> 'robots', 'content'=> 'index,follow');
             } else {
                 $head['meta'][] = array('name'=> 'robots', 'content'=> 'noindex,nofollow');
@@ -396,27 +333,35 @@ function tpl_metaheaders($alt = true) {
 
     // load stylesheets
     $head['link'][] = array(
-        'rel' => 'stylesheet', 'type'=> 'text/css',
+        'rel' => 'stylesheet',
         'href'=> DOKU_BASE.'lib/exe/css.php?t='.rawurlencode($conf['template']).'&tseed='.$tseed
     );
 
-    // make $INFO and other vars available to JavaScripts
-    $json   = new JSON();
-    $script = "var NS='".$INFO['namespace']."';";
+    $script = "var NS='".(isset($INFO)?$INFO['namespace']:'')."';";
     if($conf['useacl'] && $INPUT->server->str('REMOTE_USER')) {
-        $script .= "var SIG='".toolbar_signature()."';";
+        $script .= "var SIG=".toolbar_signature().";";
     }
-    $script .= 'var JSINFO = '.$json->encode($JSINFO).';';
-    $head['script'][] = array('type'=> 'text/javascript', '_data'=> $script);
+    jsinfo();
+    $script .= 'var JSINFO = ' . json_encode($JSINFO).';';
+    $head['script'][] = array('_data'=> $script);
 
-    // load external javascript
+    // load jquery
+    $jquery = getCdnUrls();
+    foreach($jquery as $src) {
+        $head['script'][] = array(
+            '_data' => '',
+            'src' => $src,
+        ) + ($conf['defer_js'] ? [ 'defer' => 'defer'] : []);
+    }
+
+    // load our javascript dispatcher
     $head['script'][] = array(
-        'type'=> 'text/javascript', 'charset'=> 'utf-8', '_data'=> '',
-        'src' => DOKU_BASE.'lib/exe/js.php'.'?t='.rawurlencode($conf['template']).'&tseed='.$tseed
-    );
+        '_data'=> '',
+        'src' => DOKU_BASE.'lib/exe/js.php'.'?t='.rawurlencode($conf['template']).'&tseed='.$tseed,
+    ) + ($conf['defer_js'] ? [ 'defer' => 'defer'] : []);
 
     // trigger event here
-    trigger_event('TPL_METAHEADER_OUTPUT', $head, '_tpl_metaheaders_action', true);
+    Event::createAndTrigger('TPL_METAHEADER_OUTPUT', $head, '_tpl_metaheaders_action', true);
     return true;
 }
 
@@ -436,7 +381,11 @@ function tpl_metaheaders($alt = true) {
  */
 function _tpl_metaheaders_action($data) {
     foreach($data as $tag => $inst) {
+        if($tag == 'script') {
+            echo "<!--[if gte IE 9]><!-->\n"; // no scripts for old IE
+        }
         foreach($inst as $attr) {
+            if ( empty($attr) ) { continue; }
             echo '<', $tag, ' ', buildAttributes($attr);
             if(isset($attr['_data']) || $tag == 'script') {
                 if($tag == 'script' && $attr['_data'])
@@ -450,6 +399,9 @@ function _tpl_metaheaders_action($data) {
             }
             echo "\n";
         }
+        if($tag == 'script') {
+            echo "<!--<![endif]-->\n";
+        }
     }
 }
 
@@ -484,10 +436,13 @@ function tpl_link($url, $name, $more = '', $return = false) {
  *
  * @param string      $id   page id
  * @param string|null $name the name of the link
- * @return bool true
+ * @param bool        $return
+ * @return true|string
  */
-function tpl_pagelink($id, $name = null) {
-    print '<bdi>'.html_wikilink($id, $name).'</bdi>';
+function tpl_pagelink($id, $name = null, $return = false) {
+    $out = '<bdi>'.html_wikilink($id, $name).'</bdi>';
+    if($return) return $out;
+    print $out;
     return true;
 }
 
@@ -503,12 +458,14 @@ function tpl_pagelink($id, $name = null) {
  * @return false|string
  */
 function tpl_getparent($id) {
+    $resolver = new PageResolver('root');
+
     $parent = getNS($id).':';
-    resolve_pageid('', $parent, $exists);
+    $parent = $resolver->resolveId($parent);
     if($parent == $id) {
         $pos    = strrpos(getNS($id), ':');
         $parent = substr($parent, 0, $pos).':';
-        resolve_pageid('', $parent, $exists);
+        $parent = $resolver->resolveId($parent);
         if($parent == $id) return false;
     }
     return $parent;
@@ -523,8 +480,10 @@ function tpl_getparent($id) {
  * @param string $type
  * @param bool $return
  * @return bool|string html, or false if no data, true if printed
+ * @deprecated 2017-09-01 see devel:menus
  */
 function tpl_button($type, $return = false) {
+    dbg_deprecated('see devel:menus');
     $data = tpl_get_action($type);
     if($data === false) {
         return false;
@@ -561,8 +520,10 @@ function tpl_button($type, $return = false) {
  * @param string $inner   innerHML of link
  * @param bool   $return  if true it returns html, otherwise prints
  * @return bool|string html or false if no data, true if printed
+ * @deprecated 2017-09-01 see devel:menus
  */
 function tpl_actionlink($type, $pre = '', $suf = '', $inner = '', $return = false) {
+    dbg_deprecated('see devel:menus');
     global $lang;
     $data = tpl_get_action($type);
     if($data === false) {
@@ -609,180 +570,45 @@ function tpl_actionlink($type, $pre = '', $suf = '', $inner = '', $return = fals
 /**
  * Check the actions and get data for buttons and links
  *
- * Available actions are
- *
- *  edit        - edit/create/show/draft
- *  history     - old revisions
- *  recent      - recent changes
- *  login       - login/logout - if ACL enabled
- *  profile     - user profile (if logged in)
- *  index       - The index
- *  admin       - admin page - if enough rights
- *  top         - back to top
- *  back        - back to parent - if available
- *  backlink    - links to the list of backlinks
- *  subscribe/subscription- subscribe/unsubscribe
- *
  * @author Andreas Gohr <andi@splitbrain.org>
  * @author Matthias Grimm <matthiasgrimm@users.sourceforge.net>
  * @author Adrian Lang <mail@adrianlang.de>
  *
  * @param string $type
  * @return array|bool|string
+ * @deprecated 2017-09-01 see devel:menus
  */
 function tpl_get_action($type) {
-    global $ID;
-    global $INFO;
-    global $REV;
-    global $ACT;
-    global $conf;
-    /** @var Input $INPUT */
-    global $INPUT;
-
-    // check disabled actions and fix the badly named ones
+    dbg_deprecated('see devel:menus');
     if($type == 'history') $type = 'revisions';
-    if ($type == 'subscription') $type = 'subscribe';
-    if(!actionOK($type)) return false;
+    if($type == 'subscription') $type = 'subscribe';
+    if($type == 'img_backto') $type = 'imgBackto';
 
-    $accesskey   = null;
-    $id          = $ID;
-    $method      = 'get';
-    $params      = array('do' => $type);
-    $nofollow    = true;
-    $replacement = '';
-
-    $unknown = false;
-    switch($type) {
-        case 'edit':
-            // most complicated type - we need to decide on current action
-            if($ACT == 'show' || $ACT == 'search') {
-                $method = 'post';
-                if($INFO['writable']) {
-                    $accesskey = 'e';
-                    if(!empty($INFO['draft'])) {
-                        $type         = 'draft';
-                        $params['do'] = 'draft';
-                    } else {
-                        $params['rev'] = $REV;
-                        if(!$INFO['exists']) {
-                            $type = 'create';
-                        }
-                    }
-                } else {
-                    if(!actionOK('source')) return false; //pseudo action
-                    $params['rev'] = $REV;
-                    $type          = 'source';
-                    $accesskey     = 'v';
-                }
-            } else {
-                $params    = array('do' => '');
-                $type      = 'show';
-                $accesskey = 'v';
-            }
-            break;
-        case 'revisions':
-            $type      = 'revs';
-            $accesskey = 'o';
-            break;
-        case 'recent':
-            $accesskey = 'r';
-            break;
-        case 'index':
-            $accesskey = 'x';
-            // allow searchbots to get to the sitemap from the homepage (when dokuwiki isn't providing a sitemap.xml)
-            if ($conf['start'] == $ID && !$conf['sitemap']) {
-                $nofollow = false;
-            }
-            break;
-        case 'top':
-            $accesskey = 't';
-            $params    = array('do' => '');
-            $id        = '#dokuwiki__top';
-            break;
-        case 'back':
-            $parent = tpl_getparent($ID);
-            if(!$parent) {
-                return false;
-            }
-            $id        = $parent;
-            $params    = array('do' => '');
-            $accesskey = 'b';
-            break;
-        case 'img_backto':
-            $params = array();
-            $accesskey = 'b';
-            $replacement = $ID;
-            break;
-        case 'login':
-            $params['sectok'] = getSecurityToken();
-            if($INPUT->server->has('REMOTE_USER')) {
-                if(!actionOK('logout')) {
-                    return false;
-                }
-                $params['do'] = 'logout';
-                $type         = 'logout';
-            }
-            break;
-        case 'register':
-            if($INPUT->server->str('REMOTE_USER')) {
-                return false;
-            }
-            break;
-        case 'resendpwd':
-            if($INPUT->server->str('REMOTE_USER')) {
-                return false;
-            }
-            break;
-        case 'admin':
-            if(!$INFO['ismanager']) {
-                return false;
-            }
-            break;
-        case 'revert':
-            if(!$INFO['ismanager'] || !$REV || !$INFO['writable']) {
-                return false;
-            }
-            $params['rev']    = $REV;
-            $params['sectok'] = getSecurityToken();
-            break;
-        case 'subscribe':
-            if(!$INPUT->server->str('REMOTE_USER')) {
-                return false;
-            }
-            break;
-        case 'backlink':
-            break;
-        case 'profile':
-            if(!$INPUT->server->has('REMOTE_USER')) {
-                return false;
-            }
-            break;
-        case 'media':
-            $params['ns'] = getNS($ID);
-            break;
-        case 'mediaManager':
-            // View image in media manager
-            global $IMG;
-            $imgNS = getNS($IMG);
-            $authNS = auth_quickaclcheck("$imgNS:*");
-            if ($authNS < AUTH_UPLOAD) {
-                return false;
-            }
-            $params = array(
-                'ns' => $imgNS,
-                'image' => $IMG,
-                'do' => 'media'
-            );
-            //$type = 'media';
-            break;
-        default:
-            //unknown type
-            $unknown = true;
+    $class = '\\dokuwiki\\Menu\\Item\\' . ucfirst($type);
+    if(class_exists($class)) {
+        try {
+            /** @var \dokuwiki\Menu\Item\AbstractItem $item */
+            $item = new $class;
+            $data = $item->getLegacyData();
+            $unknown = false;
+        } catch(\RuntimeException $ignored) {
+            return false;
+        }
+    } else {
+        global $ID;
+        $data = array(
+            'accesskey' => null,
+            'type' => $type,
+            'id' => $ID,
+            'method' => 'get',
+            'params' => array('do' => $type),
+            'nofollow' => true,
+            'replacement' => '',
+        );
+        $unknown = true;
     }
 
-    $data = compact('accesskey', 'type', 'id', 'method', 'params', 'nofollow', 'replacement');
-
-    $evt = new Doku_Event('TPL_ACTION_GET', $data);
+    $evt = new Event('TPL_ACTION_GET', $data);
     if($evt->advise_before()) {
         //handle unknown types
         if($unknown) {
@@ -808,8 +634,10 @@ function tpl_get_action($type) {
  * @param string        $suf suffix for links
  * @param string        $inner inner HTML for links
  * @return bool|string
+ * @deprecated 2017-09-01 see devel:menus
  */
 function tpl_action($type, $link = false, $wrapper = false, $return = false, $pre = '', $suf = '', $inner = '') {
+    dbg_deprecated('see devel:menus');
     $out = '';
     if($link) {
         $out .= tpl_actionlink($type, $pre, $suf, $inner, true);
@@ -843,20 +671,45 @@ function tpl_searchform($ajax = true, $autocomplete = true) {
     global $lang;
     global $ACT;
     global $QUERY;
+    global $ID;
 
     // don't print the search form if search action has been disabled
     if(!actionOK('search')) return false;
 
-    print '<form action="'.wl().'" accept-charset="utf-8" class="search" id="dw__search" method="get" role="search"><div class="no">';
-    print '<input type="hidden" name="do" value="search" />';
-    print '<input type="text" ';
-    if($ACT == 'search') print 'value="'.htmlspecialchars($QUERY).'" ';
-    print 'placeholder="'.$lang['btn_search'].'" ';
-    if(!$autocomplete) print 'autocomplete="off" ';
-    print 'id="qsearch__in" accesskey="f" name="id" class="edit" title="[F]" />';
-    print '<button type="submit" title="'.$lang['btn_search'].'">'.$lang['btn_search'].'</button>';
-    if($ajax) print '<div id="qsearch__out" class="ajax_qsearch JSpopup"></div>';
-    print '</div></form>';
+    $searchForm = new dokuwiki\Form\Form([
+        'action' => wl(),
+        'method' => 'get',
+        'role' => 'search',
+        'class' => 'search',
+        'id' => 'dw__search',
+    ], true);
+    $searchForm->addTagOpen('div')->addClass('no');
+    $searchForm->setHiddenField('do', 'search');
+    $searchForm->setHiddenField('id', $ID);
+    $searchForm->addTextInput('q')
+        ->addClass('edit')
+        ->attrs([
+            'title' => '[F]',
+            'accesskey' => 'f',
+            'placeholder' => $lang['btn_search'],
+            'autocomplete' => $autocomplete ? 'on' : 'off',
+        ])
+        ->id('qsearch__in')
+        ->val($ACT === 'search' ? $QUERY : '')
+        ->useInput(false)
+    ;
+    $searchForm->addButton('', $lang['btn_search'])->attrs([
+        'type' => 'submit',
+        'title' => $lang['btn_search'],
+    ]);
+    if ($ajax) {
+        $searchForm->addTagOpen('div')->id('qsearch__out')->addClass('ajax_qsearch JSpopup');
+        $searchForm->addTagClose('div');
+    }
+    $searchForm->addTagClose('div');
+
+    echo $searchForm->toHTML('QuickSearch');
+
     return true;
 }
 
@@ -866,33 +719,39 @@ function tpl_searchform($ajax = true, $autocomplete = true) {
  * @author Andreas Gohr <andi@splitbrain.org>
  *
  * @param string $sep Separator between entries
- * @return bool
+ * @param bool   $return return or print
+ * @return bool|string
  */
-function tpl_breadcrumbs($sep = '•') {
+function tpl_breadcrumbs($sep = null, $return = false) {
     global $lang;
     global $conf;
 
     //check if enabled
     if(!$conf['breadcrumbs']) return false;
 
+    //set default
+    if(is_null($sep)) $sep = '•';
+
+    $out='';
+
     $crumbs = breadcrumbs(); //setup crumb trace
 
     $crumbs_sep = ' <span class="bcsep">'.$sep.'</span> ';
 
     //render crumbs, highlight the last one
-    print '<span class="bchead">'.$lang['breadcrumb'].'</span>';
+    $out .= '<span class="bchead">'.$lang['breadcrumb'].'</span>';
     $last = count($crumbs);
     $i    = 0;
     foreach($crumbs as $id => $name) {
         $i++;
-        echo $crumbs_sep;
-        if($i == $last) print '<span class="curid">';
-        print '<bdi>';
-        tpl_link(wl($id), hsc($name), 'class="breadcrumbs" title="'.$id.'"');
-        print '</bdi>';
-        if($i == $last) print '</span>';
+        $out .= $crumbs_sep;
+        if($i == $last) $out .= '<span class="curid">';
+        $out .= '<bdi>' . tpl_link(wl($id), hsc($name), 'class="breadcrumbs" title="'.$id.'"', true) .  '</bdi>';
+        if($i == $last) $out .= '</span>';
     }
-    return true;
+    if($return) return $out;
+    print $out;
+    return $out ? true : false;
 }
 
 /**
@@ -908,9 +767,10 @@ function tpl_breadcrumbs($sep = '•') {
  * @todo   May behave strangely in RTL languages
  *
  * @param string $sep Separator between entries
- * @return bool
+ * @param bool   $return return or print
+ * @return bool|string
  */
-function tpl_youarehere($sep = ' » ') {
+function tpl_youarehere($sep = null, $return = false) {
     global $conf;
     global $ID;
     global $lang;
@@ -918,15 +778,18 @@ function tpl_youarehere($sep = ' » ') {
     // check if enabled
     if(!$conf['youarehere']) return false;
 
+    //set default
+    if(is_null($sep)) $sep = ' » ';
+
+    $out = '';
+
     $parts = explode(':', $ID);
     $count = count($parts);
 
-    echo '<span class="bchead">'.$lang['youarehere'].' </span>';
+    $out .= '<span class="bchead">'.$lang['youarehere'].' </span>';
 
     // always print the startpage
-    echo '<span class="home">';
-    tpl_pagelink(':'.$conf['start']);
-    echo '</span>';
+    $out .= '<span class="home">' . tpl_pagelink(':'.$conf['start'], null, true) . '</span>';
 
     // print intermediate namespace links
     $part = '';
@@ -936,18 +799,29 @@ function tpl_youarehere($sep = ' » ') {
         if($page == $conf['start']) continue; // Skip startpage
 
         // output
-        echo $sep;
-        tpl_pagelink($page);
+        $out .= $sep . tpl_pagelink($page, null, true);
     }
 
     // print current page, skipping start page, skipping for namespace index
-    resolve_pageid('', $page, $exists);
-    if(isset($page) && $page == $part.$parts[$i]) return true;
+    if (isset($page)) {
+        $page = (new PageResolver('root'))->resolveId($page);
+        if ($page == $part . $parts[$i]) {
+            if ($return) return $out;
+            print $out;
+            return true;
+        }
+    }
     $page = $part.$parts[$i];
-    if($page == $conf['start']) return true;
-    echo $sep;
-    tpl_pagelink($page);
-    return true;
+    if($page == $conf['start']) {
+        if($return) return $out;
+        print $out;
+        return true;
+    }
+    $out .= $sep;
+    $out .= tpl_pagelink($page, null, true);
+    if($return) return $out;
+    print $out;
+    return $out ? true : false;
 }
 
 /**
@@ -995,9 +869,9 @@ function tpl_pageinfo($ret = false) {
     $fn = $INFO['filepath'];
     if(!$conf['fullpath']) {
         if($INFO['rev']) {
-            $fn = str_replace(fullpath($conf['olddir']).'/', '', $fn);
+            $fn = str_replace($conf['olddir'].'/', '', $fn);
         } else {
-            $fn = str_replace(fullpath($conf['datadir']).'/', '', $fn);
+            $fn = str_replace($conf['datadir'].'/', '', $fn);
         }
     }
     $fn   = utf8_decodeFN($fn);
@@ -1065,7 +939,7 @@ function tpl_pagetitle($id = null, $ret = false) {
         case 'admin' :
             $page_title = $lang['btn_admin'];
             // try to get the plugin name
-            /** @var $plugin DokuWiki_Admin_Plugin */
+            /** @var $plugin AdminPlugin */
             if ($plugin = plugin_getRequestAdminPlugin()){
                 $plugin_title = $plugin->getMenuText($conf['lang']);
                 $page_title = $plugin_title ? $plugin_title : $plugin->getPluginName();
@@ -1088,6 +962,7 @@ function tpl_pagetitle($id = null, $ret = false) {
 
         // page functions
         case 'edit' :
+        case 'preview' :
             $page_title = "✎ ".$name;
             break;
 
@@ -1137,11 +1012,13 @@ function tpl_img_getTag($tags, $alt = '', $src = null) {
     global $SRC;
 
     if(is_null($src)) $src = $SRC;
+    if(is_null($src)) return $alt;
 
     static $meta = null;
     if(is_null($meta)) $meta = new JpegMeta($src);
     if($meta === false) return $alt;
     $info = cleanText($meta->getField($tags));
+    $meta = null; // garbage collect and close any file handles. See #3404
     if($info == false) return $alt;
     return $info;
 }
@@ -1196,7 +1073,7 @@ function tpl_get_img_meta() {
         if (!empty($tag[0])) {
             $t = array($tag[0]);
         }
-        if(is_array($tag[3])) {
+        if(isset($tag[3]) && is_array($tag[3])) {
             $t = array_merge($t,$tag[3]);
         }
         $value = tpl_img_getTag($t);
@@ -1224,8 +1101,8 @@ function tpl_img($maxwidth = 0, $maxheight = 0, $link = true, $params = null) {
     /** @var Input $INPUT */
     global $INPUT;
     global $REV;
-    $w = tpl_img_getTag('File.Width');
-    $h = tpl_img_getTag('File.Height');
+    $w = (int) tpl_img_getTag('File.Width');
+    $h = (int) tpl_img_getTag('File.Height');
 
     //resize to given max values
     $ratio = 1;
@@ -1270,7 +1147,7 @@ function tpl_img($maxwidth = 0, $maxheight = 0, $link = true, $params = null) {
     $p['src'] = $src;
 
     $data = array('url'=> ($link ? $url : null), 'params'=> $p);
-    return trigger_event('TPL_IMG_DISPLAY', $data, '_tpl_img_action', true);
+    return Event::createAndTrigger('TPL_IMG_DISPLAY', $data, '_tpl_img_action', true);
 }
 
 /**
@@ -1301,7 +1178,7 @@ function tpl_indexerWebBug() {
     global $ID;
 
     $p           = array();
-    $p['src']    = DOKU_BASE.'lib/exe/indexer.php?id='.rawurlencode($ID).
+    $p['src']    = DOKU_BASE.'lib/exe/taskrunner.php?id='.rawurlencode($ID).
         '&'.time();
     $p['width']  = 2; //no more 1x1 px image because we live in times of ad blockers...
     $p['height'] = 1;
@@ -1401,7 +1278,7 @@ function tpl_getLang($id) {
             }
         }
     }
-    return $lang[$id];
+    return isset($lang[$id]) ? $lang[$id] : '';
 }
 
 /**
@@ -1475,7 +1352,7 @@ function tpl_mediaContent($fromajax = false, $sort='natural') {
     // output the content pane, wrapped in an event.
     if(!$fromajax) ptln('<div id="media__content">');
     $data = array('do' => $do);
-    $evt  = new Doku_Event('MEDIAMANAGER_CONTENT_OUTPUT', $data);
+    $evt  = new Event('MEDIAMANAGER_CONTENT_OUTPUT', $data);
     if($evt->advise_before()) {
         $do = $data['do'];
         if($do == 'filesinuse') {
@@ -1545,13 +1422,20 @@ function tpl_mediaFileList() {
  * list of file revisions
  *
  * @author Kate Arzamastseva <pshns@ukr.net>
+ *
+ * @param string $image
+ * @param boolean $rev
  */
 function tpl_mediaFileDetails($image, $rev) {
     global $conf, $DEL, $lang;
     /** @var Input $INPUT */
     global $INPUT;
 
-    $removed = (!file_exists(mediaFN($image)) && file_exists(mediaMetaFN($image, '.changes')) && $conf['mediarevisions']);
+    $removed = (
+        !file_exists(mediaFN($image)) &&
+        file_exists(mediaMetaFN($image, '.changes')) &&
+        $conf['mediarevisions']
+    );
     if(!$image || (!file_exists(mediaFN($image)) && !$removed) || $DEL) return;
     if($rev && !file_exists(mediaFN($image, $rev))) $rev = false;
     $ns = getNS($image);
@@ -1578,7 +1462,9 @@ function tpl_mediaFileDetails($image, $rev) {
     list($ext) = mimetype($image, false);
     $class    = preg_replace('/[^_\-a-z0-9]+/i', '_', $ext);
     $class    = 'select mediafile mf_'.$class;
-    $tabTitle = '<strong><a href="'.ml($image).'" class="'.$class.'" title="'.$lang['mediaview'].'">'.$image.'</a>'.'</strong>';
+    $attributes = $rev ? ['rev' => $rev] : [];
+    $tabTitle = '<strong><a href="'.ml($image, $attributes).'" class="'.$class.'" title="'.$lang['mediaview'].'">'.
+        $image.'</a>'.'</strong>';
     if($opened_tab === 'view' && $rev) {
         printf($lang['media_viewold'], $tabTitle, dformat($rev));
     } else {
@@ -1625,44 +1511,12 @@ function tpl_mediaTree() {
  *
  * @param string $empty empty option label
  * @param string $button submit button label
+ * @deprecated 2017-09-01 see devel:menus
  */
 function tpl_actiondropdown($empty = '', $button = '&gt;') {
-    global $ID;
-    global $REV;
-    global $lang;
-    /** @var Input $INPUT */
-    global $INPUT;
-
-    $action_structure = array(
-        'page_tools' => array('edit', 'revert', 'revisions', 'backlink', 'subscribe'),
-        'site_tools' => array('recent', 'media', 'index'),
-        'user_tools' => array('login', 'register', 'profile', 'admin'),
-    );
-
-    echo '<form action="'.script().'" method="get" accept-charset="utf-8">';
-    echo '<div class="no">';
-    echo '<input type="hidden" name="id" value="'.$ID.'" />';
-    if($REV) echo '<input type="hidden" name="rev" value="'.$REV.'" />';
-    if ($INPUT->server->str('REMOTE_USER')) {
-        echo '<input type="hidden" name="sectok" value="'.getSecurityToken().'" />';
-    }
-
-    echo '<select name="do" class="edit quickselect" title="'.$lang['tools'].'">';
-    echo '<option value="">'.$empty.'</option>';
-
-    foreach($action_structure as $tools => $actions) {
-        echo '<optgroup label="'.$lang[$tools].'">';
-        foreach($actions as $action) {
-            $act = tpl_get_action($action);
-            if($act) echo '<option value="'.$act['params']['do'].'">'.$lang['btn_'.$act['type']].'</option>';
-        }
-        echo '</optgroup>';
-    }
-
-    echo '</select>';
-    echo '<button type="submit">'.$button.'</button>';
-    echo '</div>';
-    echo '</form>';
+    dbg_deprecated('see devel:menus');
+    $menu = new \dokuwiki\Menu\MobileMenu();
+    echo $menu->getDropdown($empty, $button);
 }
 
 /**
@@ -1739,75 +1593,11 @@ function tpl_include_page($pageid, $print = true, $propagate = false, $useacl =
  * Display the subscribe form
  *
  * @author Adrian Lang <lang@cosmocode.de>
+ * @deprecated 2020-07-23
  */
 function tpl_subscribe() {
-    global $INFO;
-    global $ID;
-    global $lang;
-    global $conf;
-    $stime_days = $conf['subscribe_time'] / 60 / 60 / 24;
-
-    echo p_locale_xhtml('subscr_form');
-    echo '<h2>'.$lang['subscr_m_current_header'].'</h2>';
-    echo '<div class="level2">';
-    if($INFO['subscribed'] === false) {
-        echo '<p>'.$lang['subscr_m_not_subscribed'].'</p>';
-    } else {
-        echo '<ul>';
-        foreach($INFO['subscribed'] as $sub) {
-            echo '<li><div class="li">';
-            if($sub['target'] !== $ID) {
-                echo '<code class="ns">'.hsc(prettyprint_id($sub['target'])).'</code>';
-            } else {
-                echo '<code class="page">'.hsc(prettyprint_id($sub['target'])).'</code>';
-            }
-            $sstl = sprintf($lang['subscr_style_'.$sub['style']], $stime_days);
-            if(!$sstl) $sstl = hsc($sub['style']);
-            echo ' ('.$sstl.') ';
-
-            echo '<a href="'.wl(
-                $ID,
-                array(
-                     'do'        => 'subscribe',
-                     'sub_target'=> $sub['target'],
-                     'sub_style' => $sub['style'],
-                     'sub_action'=> 'unsubscribe',
-                     'sectok'    => getSecurityToken()
-                )
-            ).
-                '" class="unsubscribe">'.$lang['subscr_m_unsubscribe'].
-                '</a></div></li>';
-        }
-        echo '</ul>';
-    }
-    echo '</div>';
-
-    // Add new subscription form
-    echo '<h2>'.$lang['subscr_m_new_header'].'</h2>';
-    echo '<div class="level2">';
-    $ns      = getNS($ID).':';
-    $targets = array(
-        $ID => '<code class="page">'.prettyprint_id($ID).'</code>',
-        $ns => '<code class="ns">'.prettyprint_id($ns).'</code>',
-    );
-    $styles  = array(
-        'every'  => $lang['subscr_style_every'],
-        'digest' => sprintf($lang['subscr_style_digest'], $stime_days),
-        'list'   => sprintf($lang['subscr_style_list'], $stime_days),
-    );
-
-    $form = new Doku_Form(array('id' => 'subscribe__form'));
-    $form->startFieldset($lang['subscr_m_subscribe']);
-    $form->addRadioSet('sub_target', $targets);
-    $form->startFieldset($lang['subscr_m_receive']);
-    $form->addRadioSet('sub_style', $styles);
-    $form->addHidden('sub_action', 'subscribe');
-    $form->addHidden('do', 'subscribe');
-    $form->addHidden('id', $ID);
-    $form->endFieldset();
-    $form->addElement(form_makeButton('submit', 'subscribe', $lang['subscr_m_subscribe']));
-    html_form('SUBSCRIBE', $form);
-    echo '</div>';
+    dbg_deprecated(\dokuwiki\Ui\Subscribe::class .'::show()');
+    (new \dokuwiki\Ui\Subscribe)->show();
 }
 
 /**
@@ -1818,7 +1608,7 @@ function tpl_subscribe() {
  * @author Andreas Gohr <andi@splitbrain.org>
  */
 function tpl_flush() {
-    ob_flush();
+    if( ob_get_level() > 0 ) ob_flush();
     flush();
 }
 
@@ -1829,13 +1619,15 @@ function tpl_flush() {
  * file, otherwise it is assumed to be relative to the current template
  *
  * @param  string[] $search       locations to look at
- * @param  bool     $abs           if to use absolute URL
- * @param  array   &$imginfo   filled with getimagesize()
+ * @param  bool     $abs          if to use absolute URL
+ * @param  array    &$imginfo     filled with getimagesize()
+ * @param  bool     $fallback     use fallback image if target isn't found or return 'false' if potential
+ *                                false result is required
  * @return string
  *
  * @author Andreas  Gohr <andi@splitbrain.org>
  */
-function tpl_getMediaFile($search, $abs = false, &$imginfo = null) {
+function tpl_getMediaFile($search, $abs = false, &$imginfo = null, $fallback = true) {
     $img     = '';
     $file    = '';
     $ismedia = false;
@@ -1852,6 +1644,17 @@ function tpl_getMediaFile($search, $abs = false, &$imginfo = null) {
         if(file_exists($file)) break;
     }
 
+    // manage non existing target
+    if (!file_exists($file)) {
+        // give result for fallback image
+        if ($fallback === true) {
+            $file = DOKU_INC . 'lib/images/blank.gif';
+            // stop process if false result is required (if $fallback is false)
+        } else {
+            return false;
+        }
+    }
+
     // fetch image data if requested
     if(!is_null($imginfo)) {
         $imginfo = getimagesize($file);
@@ -1999,7 +1802,7 @@ function tpl_classes() {
         'mode_'.$ACT,
         'tpl_'.$conf['template'],
         $INPUT->server->bool('REMOTE_USER') ? 'loggedIn' : '',
-        $INFO['exists'] ? '' : 'notFound',
+        (isset($INFO) && $INFO['exists']) ? '' : 'notFound',
         ($ID == $conf['start']) ? 'home' : '',
     );
     return join(' ', $classes);
@@ -2012,15 +1815,17 @@ function tpl_classes() {
  * @param string $toolsname name of menu
  * @param array $items
  * @param string $view e.g. 'main', 'detail', ...
+ * @deprecated 2017-09-01 see devel:menus
  */
 function tpl_toolsevent($toolsname, $items, $view = 'main') {
+    dbg_deprecated('see devel:menus');
     $data = array(
         'view' => $view,
         'items' => $items
     );
 
     $hook = 'TEMPLATE_' . strtoupper($toolsname) . '_DISPLAY';
-    $evt = new Doku_Event($hook, $data);
+    $evt = new Event($hook, $data);
     if($evt->advise_before()) {
         foreach($evt->data['items'] as $k => $html) echo $html;
     }
