@@ -30,12 +30,12 @@
 
 <?php
 $smi_list = '';
-foreach (glob('*.gif') as $img) {
+foreach (glob('*.svg') as $img) {
     $smi_list .= '<img src="'.$img.'" alt="'.$img.'" title="'.$img.'" /> ';
 }
 if(is_dir('local')) {
     $smi_list .= '<hr />';
-    foreach (glob('local/*.gif') as $img) {
+    foreach (glob('local/*.svg') as $img) {
         $smi_list .= '<img src="'.$img.'" alt="'.$img.'" title="'.$img.'" /> ';
     }
 }
